#ifndef __MAIN_MATH_H
#define __MAIN_MATH_H
#include "sys_config.h"
#include "FreeRTOS.h"
#include "task.h"
#include "adc_device.h"
#include "gpio_device.h"
#include "routing.h"
#include "spll_3ph_ddsrf.h"
#include "abc_dq0_pos.h"
#include "abc_dq0_neg.h"
#include "dq0_abc.h"
#include "power_meas_sine_analyzer.h"
#include "spll_3ph_dq.h"
#include "DCLF32.h"



#define ISR2_FREQUENCY_HZ 5000
#define UNIVERSAL_GRID_MAX_FREQ    65
#define UNIVERSAL_GRID_MIN_FREQ    45
#define PWM_DUTY_CLAMP ((float32_t)0.98)



#define RATED_GIRD_FREQUENCY   ((float)50)    // Unit, Hz
#define VALUE_2PI   ((float)6.283185307)    //2*PI
#define PWM_FREQ    ((float)20000)          //(16000)
#define TS    ((float)1.0/PWM_FREQ)         //sample time
#define DWT_FIRST  (float)(VALUE_2PI * RATED_GIRD_FREQUENCY)
#define PI					((float)3.1415927)

#define DECOUP_WL	(float)0.157 	//wL = 2*pi*f*L L =0.5mH

#define SQRT3		(float)1.7320508
#define SQRT3DIV3	(float)0.5773503
#define cMinPwm 	0.0001f
#define cMaxPwm 	1.0f
#define cPwmDeadTime	0.0005f	

#define  AC_FREQ_HZ ((float32_t)50)
#define  VBUS_NOMINAL_VOLTS ((float32_t)800)
#define  LI_INDUCTOR_VALUE  ((float32_t)0.347*0.001)
#define  LG_INDUCTOR_VALUE  ((float32_t)0.00934*0.001)
#define  VGRID_MAX_SENSE_VOLTS ((float32_t)450)
#define  VINV_MAX_SENSE_VOLTS TINV_VGRID_MAX_SENSE_VOLTS
#define  VBUS_MAX_SENSE_VOLTS ((float32_t)1144)
#define  IINV_MAX_SENSE_AMPS ((float32_t)19.8)
#define  IINV_TRIP_LIMIT_AMPS ((float32_t)18)
#define  IGRID_MAX_SENSE_AMPS ((float32_t)21.3)
#define  IGRID_TRIP_LIMIT_AMPS ((float32_t)21)

#define  Delta_T    0.00005f
#define  PI_V	 	3.14159265359f
#define  FLTR1_K 	0.000314159265359f				//= 2.0f * PI_V * Delta_T;


extern ABC_DQ0_POS vGrid_dq0_pos;
extern ABC_DQ0_POS vGrid_dq0_pos_filter;
extern ABC_DQ0_NEG vGrid_dq0_neg;
extern ABC_DQ0_POS iInv_dq0_pos;
extern ABC_DQ0_POS iInv_dq0_pos_filter;
extern ABC_DQ0_POS iGrid_dq0_pos;
extern DQ0_ABC vInv_dq0;
extern SPLL_3PH_DDSRF  spll_3ph_1;

extern DCL_PI dcl_gi_id;
extern DCL_PI dcl_gi_iq;
extern DCL_PI dcl_gi_iz;
extern DCL_PI dcl_gv_vBus;
extern DCL_PI dcl_gv_vBanlence;
extern float32_t dcl_gi_id_out;
extern float32_t dcl_gi_iq_out;
extern float32_t dcl_gi_iz_out;
extern float32_t dcl_gv_vBus_out;
extern float32_t dcl_gv_vBanlence_out;
extern volatile float32_t dcl_idRef;
extern volatile float32_t dcl_iqRef;
extern volatile float32_t dcl_vBusRef;
extern volatile float32_t dcl_vBusRefSlewed;
extern float32_t dcl_vdInv;
extern float32_t dcl_vqInv;
extern float32_t dcl_vzInv;
extern volatile int32_t ctl_closeGiLoop;
extern volatile int32_t ctl_closeGvLoop;

extern volatile uint16_t usRun_first_flag;
extern volatile uint16_t usDataRenew_flog;

extern float fBanlence_voltage_up;
extern float fBanlence_voltage_dw;

extern float32_t fiInv_d_filter;
extern float32_t fiInv_q_filter;

extern float32_t PWM_duty_A;
extern float32_t PWM_duty_B;
extern float32_t PWM_duty_C;
extern float32_t PWM_duty_A2;
extern float32_t PWM_duty_B2;
extern float32_t PWM_duty_C2;

//extern  float  FLTR1_K;
#define FILTER1(out,in,k,f)			\
	{								\
		f = (k)*FLTR1_K;			\
		out = (((float)1.0 - f )*(out) + f*(in));	\
	}

#define POSITIVE_ABC_MAX(a,b,c,max)	\
	{						\
	if(a > b)			\
		max = a;		\
	else				\
		max = b;		\
	if(max < c)		\
		max = c;		\
}
#define POSITIVE_ABC_MAX_MIN(a,b,c,max,min)	\
{						\
	if(a > b)			\
		{				\
		if( a > c)		\
			max = a;	\
		else			\
			max = c;	\
		if( b > c)		\
			min = c;	\
		else			\
			min = b;	\
		}				\
	else				\
		{				\
		if( b > c)		\
			max = b;	\
		else			\
			max = c;	\
		if( a > c)		\
			min = c;	\
		else			\
			min = a;	\
		}				\
}

extern Sys_dt_t rout_data;
extern volatile TCurrCtrl  CurrCtrlObject;
extern volatile TBusCtrl BusCtrlObject;
extern volatile TBusCtrl NegIqCtrlObject;

#pragma FUNC_ALWAYS_INLINE(HAL_readADadnDeal)
static inline void HAL_readADadnDeal(void)
{
	float temp1,temp2,temp3;
	float temp12,temp23,temp31;

	temp1 = ((float)CONF_VINV_A_READ - rout_data.Calib_Para.sOffset_coeff1)*rout_data.Calib_Para.fMultip_radio1;
	temp2 = ((float)CONF_VINV_B_READ - rout_data.Calib_Para.sOffset_coeff2)*rout_data.Calib_Para.fMultip_radio2;
	temp3 = ((float)CONF_VINV_C_READ - rout_data.Calib_Para.sOffset_coeff3)*rout_data.Calib_Para.fMultip_radio3;

	temp12 = temp1 - temp2;
	temp23 = temp2 - temp3;
	temp31 = temp3 - temp1;
	
	rout_data.Inst_data.fInvert_voltage_U_inst = (temp12 - temp31) * 0.333333333334f;
	rout_data.Inst_data.fInvert_voltage_V_inst = (temp23 - temp12) * 0.333333333334f;
	rout_data.Inst_data.fInvert_voltage_W_inst = (temp31 - temp23) * 0.333333333334f;

	rout_data.Inst_data.fInvert_current_U1_inst= ((float)CONF_IINV_MA_READ - rout_data.Calib_Para.sOffset_coeff4)*rout_data.Calib_Para.fMultip_radio4;
	rout_data.Inst_data.fInvert_current_V1_inst= ((float)CONF_IINV_MB_READ - rout_data.Calib_Para.sOffset_coeff5)*rout_data.Calib_Para.fMultip_radio5;
	rout_data.Inst_data.fInvert_current_W1_inst= ((float)CONF_IINV_MC_READ - rout_data.Calib_Para.sOffset_coeff6)*rout_data.Calib_Para.fMultip_radio6;

	rout_data.Inst_data.fInvert_current_U2_inst= ((float)CONF_IINV_FA_READ - rout_data.Calib_Para.sOffset_coeff7)*rout_data.Calib_Para.fMultip_radio7;
	rout_data.Inst_data.fInvert_current_V2_inst= ((float)CONF_IINV_FB_READ - rout_data.Calib_Para.sOffset_coeff8)*rout_data.Calib_Para.fMultip_radio8;
	rout_data.Inst_data.fInvert_current_W2_inst= ((float)CONF_IINV_FC_READ - rout_data.Calib_Para.sOffset_coeff9)*rout_data.Calib_Para.fMultip_radio9;
	
	rout_data.Inst_data.fGrid_current_A_inst   = ((float)CONF_IGRID_A_READ - rout_data.Calib_Para.sOffset_coeff10)*rout_data.Calib_Para.fMultip_radio10;
	rout_data.Inst_data.fGrid_current_B_inst   = ((float)CONF_IGRID_B_READ - rout_data.Calib_Para.sOffset_coeff11)*rout_data.Calib_Para.fMultip_radio11;
	rout_data.Inst_data.fGrid_current_C_inst   = ((float)CONF_IGRID_C_READ - rout_data.Calib_Para.sOffset_coeff12)*rout_data.Calib_Para.fMultip_radio12;

	rout_data.Inst_data.fDCbat_voltage_inst    = ((float)CONF_VBUS_READ + 0.761589404f) * 0.303030303f;
												//((float)CONF_VBUS_READ	   - rout_data.Calib_Para.sOffset_coeff13)*rout_data.Calib_Para.fMultip_radio13;
}

extern uint16_t sTempBuf[2][8];
static inline void HAL_readADchannelDeal(uint16_t num,uint16_t ch)
{
	float tmp1,tmp2,tmp3;
	float tmp12,tmp23,tmp31;
	switch(num)
		{
		case 0:
			rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			rout_data.Inst_data.fDCbusMP_voltage_inst 	= ((float)CONF_U88CS_READ + 0.977227327f) * 0.1564375f;		
			rout_data.Inst_data.fDCbusMN_voltage_inst 	= ((float)CONF_U43CS_READ - 2.534058847f) * 0.154099379f;
			sTempBuf[ch][1] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y6;
			break;
		case 1:
			tmp1 = ((float)(CONF_U87CS_READ) - rout_data.Calib_Para.sOffset_coeff18) * rout_data.Calib_Para.fMultip_radio18;
			tmp2 = ((float)(CONF_U88CS_READ) - rout_data.Calib_Para.sOffset_coeff19) * rout_data.Calib_Para.fMultip_radio19;
			tmp3 = ((float)(CONF_U43CS_READ) - rout_data.Calib_Para.sOffset_coeff20) * rout_data.Calib_Para.fMultip_radio20; 
			sTempBuf[ch][6] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y1;
			break;
		case 2:
			rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			rout_data.Inst_data.fDCbusMP_voltage_inst 	= ((float)CONF_U88CS_READ + 0.977227327f) * 0.1564375f;		
			rout_data.Inst_data.fDCbusMN_voltage_inst 	= ((float)CONF_U43CS_READ - 2.534058847f) * 0.154099379f;
			sTempBuf[ch][1] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y0;
			break;
		case 3:
			rout_data.Inst_data.fOffGrid_voltage_A_inst = (float)CONF_U87CS_READ;
			rout_data.Inst_data.fOffGrid_voltage_B_inst = (float)CONF_U88CS_READ;
			rout_data.Inst_data.fOffGrid_voltage_C_inst = (float)CONF_U43CS_READ;
			//rout_data.Inst_data.fTemperature1_inst		= (float)CONF_TEMP_READ;
			M4051_OUT_Y1;
			break;
		case 4:
			rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			rout_data.Inst_data.fDCbusMP_voltage_inst 	= ((float)CONF_U88CS_READ + 0.977227327f) * 0.1564375f;		
			rout_data.Inst_data.fDCbusMN_voltage_inst 	= ((float)CONF_U43CS_READ - 2.534058847f) * 0.154099379f;
			sTempBuf[ch][1] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y6;
			break;
		case 5:
			tmp1 = ((float)(CONF_U87CS_READ) - rout_data.Calib_Para.sOffset_coeff18) * rout_data.Calib_Para.fMultip_radio18;
			tmp2 = ((float)(CONF_U88CS_READ) - rout_data.Calib_Para.sOffset_coeff19) * rout_data.Calib_Para.fMultip_radio19;
			tmp3 = ((float)(CONF_U43CS_READ) - rout_data.Calib_Para.sOffset_coeff20) * rout_data.Calib_Para.fMultip_radio20; 
			sTempBuf[ch][6] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y1;
			break;
		case 6:
			rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			rout_data.Inst_data.fDCbusMP_voltage_inst 	= ((float)CONF_U88CS_READ + 0.977227327f) * 0.1564375f;		
			rout_data.Inst_data.fDCbusMN_voltage_inst 	= ((float)CONF_U43CS_READ - 2.534058847f) * 0.154099379f;
			sTempBuf[ch][1] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y2;
			break;
		case 7:
			//rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			//rout_data.Inst_data.fDCbusP_voltage_inst 	= (float)CONF_U88CS_READ;
			//rout_data.Inst_data.fDCbusN_voltage_inst 	= (float)CONF_U43CS_READ;
			sTempBuf[ch][2] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y1;
			break;
		case 8:
			rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			rout_data.Inst_data.fDCbusMP_voltage_inst 	= ((float)CONF_U88CS_READ + 0.977227327f) * 0.1564375f;		
			rout_data.Inst_data.fDCbusMN_voltage_inst 	= ((float)CONF_U43CS_READ - 2.534058847f) * 0.154099379f;
			sTempBuf[ch][1] = (float)CONF_TEMP_READ;
			M4051_OUT_Y6;
			break;
		case 9:
			tmp1 = ((float)(CONF_U87CS_READ) - rout_data.Calib_Para.sOffset_coeff18) * rout_data.Calib_Para.fMultip_radio18;
			tmp2 = ((float)(CONF_U88CS_READ) - rout_data.Calib_Para.sOffset_coeff19) * rout_data.Calib_Para.fMultip_radio19;
			tmp3 = ((float)(CONF_U43CS_READ) - rout_data.Calib_Para.sOffset_coeff20) * rout_data.Calib_Para.fMultip_radio20; 
			sTempBuf[ch][6] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y1;
			break;
		case 10:
			rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			rout_data.Inst_data.fDCbusMP_voltage_inst 	= ((float)CONF_U88CS_READ + 0.977227327f) * 0.1564375f;		
			rout_data.Inst_data.fDCbusMN_voltage_inst 	= ((float)CONF_U43CS_READ - 2.534058847f) * 0.154099379f;
			sTempBuf[ch][1] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y3;
			break;
		case 11:
			//rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			//rout_data.Inst_data.fDCbusP_voltage_inst 	= (float)CONF_U88CS_READ;
			rout_data.Inst_data.fVref3_monitor_inst 	= (float)CONF_U43CS_READ;
			sTempBuf[ch][3] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y1;
			break;
		case 12:
			rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			rout_data.Inst_data.fDCbusMP_voltage_inst 	= ((float)CONF_U88CS_READ + 0.977227327f) * 0.1564375f;		
			rout_data.Inst_data.fDCbusMN_voltage_inst 	= ((float)CONF_U43CS_READ - 2.534058847f) * 0.154099379f;
			sTempBuf[ch][1] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y6;
			break;
		case 13:
			tmp1 = ((float)(CONF_U87CS_READ) - rout_data.Calib_Para.sOffset_coeff18) * rout_data.Calib_Para.fMultip_radio18;
			tmp2 = ((float)(CONF_U88CS_READ) - rout_data.Calib_Para.sOffset_coeff19) * rout_data.Calib_Para.fMultip_radio19;
			tmp3 = ((float)(CONF_U43CS_READ) - rout_data.Calib_Para.sOffset_coeff20) * rout_data.Calib_Para.fMultip_radio20; 
			sTempBuf[ch][6] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y1;
			break;
		case 14:
			rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			rout_data.Inst_data.fDCbusMP_voltage_inst 	= ((float)CONF_U88CS_READ + 0.977227327f) * 0.1564375f;		
			rout_data.Inst_data.fDCbusMN_voltage_inst 	= ((float)CONF_U43CS_READ - 2.534058847f) * 0.154099379f;
			sTempBuf[ch][1] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y4;
			break;
		case 15:
			rout_data.Inst_data.fInvert_voltage_filter_U_inst = (float)CONF_U87CS_READ;
			rout_data.Inst_data.fInvert_voltage_filter_V_inst = (float)CONF_U88CS_READ;
			rout_data.Inst_data.fInvert_voltage_filter_W_inst = (float)CONF_U43CS_READ;

			sTempBuf[ch][4] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y1;
			break;
		case 16:
			rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			rout_data.Inst_data.fDCbusMP_voltage_inst 	= ((float)CONF_U88CS_READ + 0.977227327f) * 0.1564375f;		
			rout_data.Inst_data.fDCbusMN_voltage_inst 	= ((float)CONF_U43CS_READ - 2.534058847f) * 0.154099379f;
			sTempBuf[ch][1] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y6;
			break;
		case 17:
			tmp1 = ((float)(CONF_U87CS_READ) - rout_data.Calib_Para.sOffset_coeff18) * rout_data.Calib_Para.fMultip_radio18;
			tmp2 = ((float)(CONF_U88CS_READ) - rout_data.Calib_Para.sOffset_coeff19) * rout_data.Calib_Para.fMultip_radio19;
			tmp3 = ((float)(CONF_U43CS_READ) - rout_data.Calib_Para.sOffset_coeff20) * rout_data.Calib_Para.fMultip_radio20; 
			sTempBuf[ch][6] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y1;
			break;
		case 18:
			rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			rout_data.Inst_data.fDCbusMP_voltage_inst 	= ((float)CONF_U88CS_READ + 0.977227327f) * 0.1564375f;		
			rout_data.Inst_data.fDCbusMN_voltage_inst 	= ((float)CONF_U43CS_READ - 2.534058847f) * 0.154099379f;
			sTempBuf[ch][1] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y5;
			break;
		case 19:
			rout_data.Inst_data.fDCbusFN_voltage_inst 	= (float)CONF_U88CS_READ;
			rout_data.Inst_data.fDCbusFP_voltage_inst 	= (float)CONF_U43CS_READ;
			sTempBuf[ch][5] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y1;
			break;
		case 20:
			rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			rout_data.Inst_data.fDCbusMP_voltage_inst 	= ((float)CONF_U88CS_READ + 0.977227327f) * 0.1564375f;		
			rout_data.Inst_data.fDCbusMN_voltage_inst 	= ((float)CONF_U43CS_READ - 2.534058847f) * 0.154099379f;
			sTempBuf[ch][1] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y6;
			break;
		case 21:
			tmp1 = ((float)(CONF_U87CS_READ) - rout_data.Calib_Para.sOffset_coeff18) * rout_data.Calib_Para.fMultip_radio18;
			tmp2 = ((float)(CONF_U88CS_READ) - rout_data.Calib_Para.sOffset_coeff19) * rout_data.Calib_Para.fMultip_radio19;
			tmp3 = ((float)(CONF_U43CS_READ) - rout_data.Calib_Para.sOffset_coeff20) * rout_data.Calib_Para.fMultip_radio20; 
			//rout_data.Inst_data.fGrid_voltage_A_inst = ((float)(CONF_U87CS_READ) - rout_data.Calib_Para.sOffset_coeff18) * rout_data.Calib_Para.fMultip_radio18;
			//rout_data.Inst_data.fGrid_voltage_B_inst = ((float)(CONF_U88CS_READ) - rout_data.Calib_Para.sOffset_coeff19) * rout_data.Calib_Para.fMultip_radio19;
			//rout_data.Inst_data.fGrid_voltage_C_inst = ((float)(CONF_U43CS_READ) - rout_data.Calib_Para.sOffset_coeff20) * rout_data.Calib_Para.fMultip_radio20; 
			sTempBuf[ch][6] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y1;
			break;
		case 22:
			rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			rout_data.Inst_data.fDCbusMP_voltage_inst 	= ((float)CONF_U88CS_READ + 0.977227327f) * 0.1564375f;		
			rout_data.Inst_data.fDCbusMN_voltage_inst 	= ((float)CONF_U43CS_READ - 2.534058847f) * 0.154099379f;
			sTempBuf[ch][1] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y7;
			break;
		case 23:
			sTempBuf[ch][7] = (float)CONF_TEMP_READ;	
			
			M4051_OUT_Y1;
			if(ch == 0)
				{
				M4051_OUT_U86;
				}
			else
				{
				M4051_OUT_U85;
				}
			break;
		default:
			break;
		}
	
		tmp12 = tmp1 - tmp2;
		tmp23 = tmp2 - tmp3;
		tmp31 = tmp3 - tmp1;
		//if((num == 1)||(num == 5)||(num == 9)||(num == 13)||(num == 17)||(num == 21))
		if((num%4) == 1)
			{
			rout_data.Inst_data.fGrid_voltage_A_inst = (tmp12 - tmp31) * 0.333333333334f;
			rout_data.Inst_data.fGrid_voltage_B_inst = (tmp23 - tmp12) * 0.333333333334f;
			rout_data.Inst_data.fGrid_voltage_C_inst = (tmp31 - tmp23) * 0.333333333334f;
			}
		/*{
		case 0 :
			rout_data.Inst_data.fOffGrid_voltage_A_inst = (float)CONF_U87CS_READ;
			rout_data.Inst_data.fOffGrid_voltage_B_inst = (float)CONF_U88CS_READ;
			rout_data.Inst_data.fOffGrid_voltage_C_inst = (float)CONF_U43CS_READ;
			//rout_data.Inst_data.fTemperature1_inst		= (float)CONF_TEMP_READ;
			sTempBuf[ch][0] = (float)CONF_TEMP_READ;			
			M4051_OUT_Y1;
			break;
		case 1 :
			rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			rout_data.Inst_data.fDCbusMP_voltage_inst 	= ((float)CONF_U88CS_READ + 0.977227327f) * 0.1564375f;		
			rout_data.Inst_data.fDCbusMN_voltage_inst 	= ((float)CONF_U43CS_READ - 2.534058847f) * 0.154099379f;
			sTempBuf[ch][1] = (float)CONF_TEMP_READ;		
			M4051_OUT_Y2;
			break;
		case 2 :
			//rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			//rout_data.Inst_data.fDCbusP_voltage_inst 	= (float)CONF_U88CS_READ;
			//rout_data.Inst_data.fDCbusN_voltage_inst 	= (float)CONF_U43CS_READ;
			sTempBuf[ch][2] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y3;
			break;
		case 3 :
			//rout_data.Inst_data.fV12_monitor_inst 		= (float)CONF_U87CS_READ;
			//rout_data.Inst_data.fDCbusP_voltage_inst 	= (float)CONF_U88CS_READ;
			rout_data.Inst_data.fVref3_monitor_inst 	= (float)CONF_U43CS_READ;
			sTempBuf[ch][3] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y4;
			//M4051_OUT_U86;
			break;
		case 4 :
			
			rout_data.Inst_data.fInvert_voltage_filter_U_inst = (float)CONF_U87CS_READ;
			rout_data.Inst_data.fInvert_voltage_filter_V_inst = (float)CONF_U88CS_READ;
			rout_data.Inst_data.fInvert_voltage_filter_W_inst = (float)CONF_U43CS_READ;

			sTempBuf[ch][4] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y5;
			break;
		case 5 :
			rout_data.Inst_data.fDCbusFN_voltage_inst 	= (float)CONF_U88CS_READ;
			rout_data.Inst_data.fDCbusFP_voltage_inst 	= (float)CONF_U43CS_READ;
			sTempBuf[ch][5] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y6;
			break;
		case 6 :
			rout_data.Inst_data.fGrid_voltage_A_inst = ((float)(CONF_U87CS_READ) - rout_data.Calib_Para.sOffset_coeff18) * rout_data.Calib_Para.fMultip_radio18;
			rout_data.Inst_data.fGrid_voltage_B_inst = ((float)(CONF_U88CS_READ) - rout_data.Calib_Para.sOffset_coeff19) * rout_data.Calib_Para.fMultip_radio19;
			rout_data.Inst_data.fGrid_voltage_C_inst = ((float)(CONF_U43CS_READ) - rout_data.Calib_Para.sOffset_coeff20) * rout_data.Calib_Para.fMultip_radio20; 
			sTempBuf[ch][6] = (float)CONF_TEMP_READ;	
			M4051_OUT_Y7;
			break;
		case 7 :

			sTempBuf[ch][7] = (float)CONF_TEMP_READ;	
			
			M4051_OUT_Y0;
			if(ch == 0)
				{
				M4051_OUT_U86;
				}
			else
				{
				M4051_OUT_U85;
				}
			
			break;

		default:
			break;
		}*/
}


/*
extern SPLL_3PH_DDSRF  spll_3ph_1;
#pragma CODE_SECTION(vRunSPLL,".TI.ramfunc");
static inline void vRunSPLL(float32_t v_p_d, float32_t v_n_d,
                                float32_t v_p_q, float32_t v_n_q)
{

        SPLL_3PH_DDSRF_run(&spll_3ph_1,
                           v_p_d, v_n_d,
                           v_p_q, v_n_q);

        rout_data.Inst_data.fPll_angle = spll_3ph_1.theta[1];

}*/

extern POWER_MEAS_SINE_ANALYZER SYS_sine_mains_A;
extern POWER_MEAS_SINE_ANALYZER SYS_sine_mains_B;
extern POWER_MEAS_SINE_ANALYZER SYS_sine_mains_C;
extern POWER_MEAS_SINE_ANALYZER LOAD_sine_mains_A;
extern POWER_MEAS_SINE_ANALYZER LOAD_sine_mains_B;
extern POWER_MEAS_SINE_ANALYZER LOAD_sine_mains_C;

static inline void vPower_meas_sine(void)
{
	SYS_sine_mains_A.v = rout_data.Inst_data.fGrid_voltage_A_inst;
	SYS_sine_mains_B.v = rout_data.Inst_data.fGrid_voltage_B_inst;
	SYS_sine_mains_C.v = rout_data.Inst_data.fGrid_voltage_C_inst;	
	SYS_sine_mains_A.i = rout_data.Inst_data.fGrid_current_A_inst;
	SYS_sine_mains_B.i = rout_data.Inst_data.fGrid_current_B_inst;
	SYS_sine_mains_C.i = rout_data.Inst_data.fGrid_current_C_inst;

	POWER_MEAS_SINE_ANALYZER_run(&SYS_sine_mains_A);
    POWER_MEAS_SINE_ANALYZER_run(&SYS_sine_mains_B);
    POWER_MEAS_SINE_ANALYZER_run(&SYS_sine_mains_C);

	rout_data.Value1_data.fGrid_voltage_A = SYS_sine_mains_A.vRms;
	rout_data.Value1_data.fGrid_voltage_B = SYS_sine_mains_B.vRms;
	rout_data.Value1_data.fGrid_voltage_C = SYS_sine_mains_C.vRms;
	rout_data.Value1_data.fGrid_current_A = SYS_sine_mains_A.iRms;
	rout_data.Value1_data.fGrid_current_B = SYS_sine_mains_B.iRms;
	rout_data.Value1_data.fGrid_current_C = SYS_sine_mains_C.iRms;	
	rout_data.Value1_data.fPower_factor_A = SYS_sine_mains_A.powerFactor;
	rout_data.Value1_data.fPower_factor_B = SYS_sine_mains_B.powerFactor;
	rout_data.Value1_data.fPower_factor_C = SYS_sine_mains_C.powerFactor;
	rout_data.Value1_data.fGrid_activeP_avg = (SYS_sine_mains_A.pRms + SYS_sine_mains_B.pRms + SYS_sine_mains_C.pRms)*0.001f;
	rout_data.Value1_data.fGrid_apparentP_avg= (SYS_sine_mains_A.vaRms + SYS_sine_mains_B.vaRms + SYS_sine_mains_C.vaRms)*0.001f;
	rout_data.Value1_data.fSys_frequ_avg = SYS_sine_mains_A.acFreqAvg;
	if((rout_data.Value1_data.fGrid_apparentP_avg >  rout_data.Value1_data.fGrid_activeP_avg)&&(rout_data.Value1_data.fGrid_activeP_avg > 0))
		rout_data.Value1_data.fGrid_reactiveP_avg = sqrtf(rout_data.Value1_data.fGrid_apparentP_avg*rout_data.Value1_data.fGrid_apparentP_avg - rout_data.Value1_data.fGrid_activeP_avg*rout_data.Value1_data.fGrid_activeP_avg);

	LOAD_sine_mains_A.v = rout_data.Inst_data.fInvert_voltage_U_inst;
	LOAD_sine_mains_B.v = rout_data.Inst_data.fInvert_voltage_V_inst;
	LOAD_sine_mains_C.v = rout_data.Inst_data.fInvert_voltage_W_inst;	
	LOAD_sine_mains_A.i = rout_data.Inst_data.fInvert_current_U1_inst;
	LOAD_sine_mains_B.i = rout_data.Inst_data.fInvert_current_V1_inst;
	LOAD_sine_mains_C.i = rout_data.Inst_data.fInvert_current_W1_inst;

	POWER_MEAS_SINE_ANALYZER_run(&LOAD_sine_mains_A);
    POWER_MEAS_SINE_ANALYZER_run(&LOAD_sine_mains_B);
    POWER_MEAS_SINE_ANALYZER_run(&LOAD_sine_mains_C);

	rout_data.Value1_data.fInvert_voltage_U = LOAD_sine_mains_A.vRms;
	rout_data.Value1_data.fInvert_voltage_V = LOAD_sine_mains_B.vRms;
	rout_data.Value1_data.fInvert_voltage_W = LOAD_sine_mains_C.vRms;
	rout_data.Value1_data.fInvert_current_U = LOAD_sine_mains_A.iRms;
	rout_data.Value1_data.fInvert_current_V = LOAD_sine_mains_B.iRms;
	rout_data.Value1_data.fInvert_current_W = LOAD_sine_mains_C.iRms;	
	rout_data.Value1_data.fLoad_activeP_avg = (LOAD_sine_mains_A.pRms + LOAD_sine_mains_B.pRms + LOAD_sine_mains_C.pRms)*0.001f;
	rout_data.Value1_data.fLoad_apparentP_avg= (LOAD_sine_mains_A.vaRms + LOAD_sine_mains_B.vaRms + LOAD_sine_mains_C.vaRms)*0.001f;
	rout_data.Value1_data.fLoadPower_factor = LOAD_sine_mains_A.powerFactor;
	if((rout_data.Value1_data.fLoad_apparentP_avg > rout_data.Value1_data.fLoad_activeP_avg)&&(rout_data.Value1_data.fLoad_activeP_avg > 0))
		rout_data.Value1_data.fLoad_reactiveP_avg = sqrtf(rout_data.Value1_data.fLoad_apparentP_avg*rout_data.Value1_data.fLoad_apparentP_avg - rout_data.Value1_data.fLoad_activeP_avg*rout_data.Value1_data.fLoad_activeP_avg);
}








void vGobalVariablesInit(void);
volatile void vSVModu(float32_t fAlaph, float32_t fBelta, float32_t fSvIa, float32_t fSvIb, float32_t fSvIc, float32_t fBusdiff);
volatile void vSequenceSep(void);
volatile void vRunVoltageLoop2(void);
volatile void vRunCurrentLoop2(void);


#endif 
