/*
 * heartbeat.c
 *
 *  Created on: 2023128
 *      Author: QA
 */
#include "sys_config.h"
#include "FreeRTOS.h"
#include "task.h"
#include "led_device.h"
#include "pwm_device.h"
#include "adc_device.h"
#include "gpio_device.h"
#include "ecap_device.h"
#include "sysmanage.h"
#include "routing.h"
#include "DCLF32.h"
#include "main_math.h"

#ifdef _USE_WATCHDOG
#include "watchdog_device.h"
#endif

#define STACK_SIZE  256U

static StaticTask_t sysManageTaskBuffer;
static StackType_t  sysManageTaskStack[STACK_SIZE];

extern Sys_dt_t rout_data;
extern volatile  float32_t slow_slip;
extern volatile int32_t ctl_closeGiLoop;
extern volatile int32_t ctl_closeGvLoop;
extern volatile int32_t ctl_pll_ref;
extern volatile float32_t dcl_idRef;
extern volatile float32_t dcl_iqRef;
extern volatile float32_t dcl_vBusRef;
extern volatile float32_t dcl_vBusRefSlewed;
extern DCL_PI dcl_gi_id;
extern DCL_PI dcl_gi_iq;
extern DCL_PI dcl_gv_vBus;

extern volatile uint16_t usRun_first_flag;
extern volatile uint16_t usGridInvert_syn ;
extern volatile uint16_t usDcvoltage_syn ;
extern float32_t fPll_angle_step;
extern  float32_t fLCL_cur_Kp;
extern float32_t fRC_pwm_KP;
extern float32_t fRC_pwm_KC;
extern float32_t k_ce;

extern volatile TCurrCtrl CurrCtrlObject;

//-------------------------------------------------------------------------------------------------
void vsysManageTask(void * pvParameters)
{
//    uint16_t ln;
	uint16_t usTaskCount = 0;
	uint16_t usStopCount = 0;
	uint16_t usRun_stop_prev = 0;
	uint16_t usRun_stop_flag = RUNSTOP_IDLE;
	uint16_t usInvert_Frequ_set_prev = 0;
	float fTemp;
	float fBusSlew_step = 0.0f;
	uint16_t usFirst_Reset = 0;
	uint16_t usFirst_ResetCount = 0;
	uint16_t usFanSpeed = 0;
    for(;;)
    {
        #ifdef _USE_WATCHDOG
        uswatchdogTaskMask |= WD_TASK_MASK_SYSMANAGE;
        #endif

        vTaskDelay(20 / portTICK_PERIOD_MS);//200->1S 20->0.1S
		if(usFirst_Reset == 0)//ܲλһ
			{
			if(rout_data.Calib_Para.fMultip_radio1 != 0)
				{
				if(usFirst_ResetCount++ > 50)
					{
					RESET_ERR_MICRO;
					usFirst_Reset = 1;
					}
				
				}
			}

		if(rout_data.Set_Para.usLocal_minute_set == 0)
			{
			POSITIVE_ABC_MAX(rout_data.Value1_data.fGrid_current_A,rout_data.Value1_data.fGrid_current_B,rout_data.Value1_data.fGrid_current_C,fTemp);
			usFanSpeed = fTemp * 4.0f;
			if(usFanSpeed < FANSPEED_MIN) usFanSpeed = FANSPEED_MIN;
			if(usFanSpeed > FANSPEED_MAX) usFanSpeed = FANSPEED_MAX;
			HAL_updateFANPWMduty(usFanSpeed);
			}
		else
			{
			HAL_updateFANPWMduty(rout_data.Set_Para.usLocal_minute_set);
			}
	
		//usGridInvert_syn = 1;
		//usDcvoltage_syn = 1;

		if(usInvert_Frequ_set_prev != rout_data.Set_Para.usInvert_Frequ_set)
			{
			if(rout_data.Set_Para.usInvert_Frequ_set > 65)rout_data.Set_Para.usInvert_Frequ_set = 65;
			if(rout_data.Set_Para.usInvert_Frequ_set < 35)rout_data.Set_Para.usInvert_Frequ_set = 35;
			
			fPll_angle_step = 3.1415927f * (float)rout_data.Set_Para.usInvert_Frequ_set * 0.0001f;
			
			usInvert_Frequ_set_prev = rout_data.Set_Para.usInvert_Frequ_set;

			rout_data.Inst_data.fPll_angle = 0;
			}

		

		switch(rout_data.Set_Para.usRun_mode)
			{
			case CHARGE:
				rout_data.Value2_data.usCharge_states = CHARGE_EN;
				ctl_pll_ref = 0;
				ctl_closeGvLoop = 1;
				ctl_closeGiLoop = 1;

				rout_data.Set_Para.sDc_Current_set = rout_data.Set_Para.sDc_Power_set;

				dcl_idRef = rout_data.Set_Para.usDc_Voltage_set;					//ߵѹ
				dcl_iqRef = rout_data.Set_Para.sAc_reactivePower_set * slow_slip;	//޹
				break;
			case DISCHARGE:
				rout_data.Value2_data.usCharge_states = CHARGE_DIS;
				ctl_pll_ref = 0;
				ctl_closeGvLoop = 0;
				ctl_closeGiLoop = 1;

				rout_data.Set_Para.sDc_Current_set = rout_data.Set_Para.sDc_Power_set;
				
				dcl_idRef = rout_data.Set_Para.sDc_Current_set * slow_slip;	//ʵҪģʽ㣬ĿǰֱӸ
				dcl_iqRef = rout_data.Set_Para.sAc_reactivePower_set * slow_slip;
				
			//	if((dcl_idRef>0.0f)&&(dcl_idRef<MIN_CURRUNT_TH))
			//		dcl_idRef = MIN_CURRUNT_TH;
			//	if((dcl_idRef<0.0f)&&(dcl_idRef>-MIN_CURRUNT_TH))
			//		dcl_idRef = -MIN_CURRUNT_TH;
				break;
			case DISCHARGE_OFF:
				rout_data.Value2_data.usCharge_states = CHARGE_DIS;
				ctl_pll_ref = 1;//ο໷
				ctl_closeGvLoop = 0;
				ctl_closeGiLoop = 0;
				break;
			default:
				rout_data.Value2_data.usCharge_states = 0;
				ctl_closeGvLoop = 0;
				ctl_closeGiLoop = 0;
				break;
			}

			

			
		//ز
		//if(rout_data.Value2_data.usRun_mode_states == DEVICE_ILDE)
			{
			dcl_gi_id.Kp = (float)rout_data.Set_Para.usLoop_LsCurrent_KP*0.1f;
			dcl_gi_id.Ki = (float)rout_data.Set_Para.usLoop_LsCurrent_KI*0.001f;
			dcl_gi_iq.Kp = (float)rout_data.Set_Para.usLoop_LsCurrent_KP*0.1f;
			dcl_gi_iq.Ki = (float)rout_data.Set_Para.usLoop_LsCurrent_KI*0.001f;
			dcl_gi_iz.Kp = (float)rout_data.Set_Para.usLoop_LsCurrent_KP*0.1f;
			dcl_gi_iz.Ki = (float)rout_data.Set_Para.usLoop_LsCurrent_KI*0.001f;
			
			dcl_gv_vBus.Kp = (float)rout_data.Set_Para.usLoop_dcVoltage_KP*0.1f;
			dcl_gv_vBus.Ki = (float)rout_data.Set_Para.usLoop_dcVoltage_KI*0.001f;

			dcl_gv_vBanlence.Kp = (float)rout_data.Set_Para.usLoop_dcBalenceVoltage_KP*0.1f;
			dcl_gv_vBanlence.Ki = (float)rout_data.Set_Para.usLoop_dcBalenceVoltage_KI*0.001f;

			fLCL_cur_Kp = (float)rout_data.Set_Para.usLoop_acVoltage_KP*0.1f;
			
			k_ce = (float)rout_data.Set_Para.usLoop_acVoltage_KI*0.01f;
			fRC_pwm_KP = (float)rout_data.Set_Para.usLoop_acRms_KP*0.01f;
			fRC_pwm_KC = (float)rout_data.Set_Para.usLoop_acRms_KI*0.001f;


			CurrCtrlObject.nKp = (float)rout_data.Set_Para.usLoop_LsCurrent_KP*0.1f;
			CurrCtrlObject.nKi = (float)rout_data.Set_Para.usLoop_LsCurrent_KI*0.01f;
			CurrCtrlObject.nKc = 0.0f;

			BusCtrlObject.nKp = (float)rout_data.Set_Para.usLoop_dcVoltage_KP*0.1f;
			BusCtrlObject.nKi = (float)rout_data.Set_Para.usLoop_dcVoltage_KI*0.01f;
			BusCtrlObject.nKc = 0.0f;

			NegIqCtrlObject.nKp = (float)rout_data.Set_Para.usLoop_dcVoltage_KP*0.1f;
			NegIqCtrlObject.nKi = (float)rout_data.Set_Para.usLoop_dcVoltage_KI*0.01f;
			NegIqCtrlObject.nKc = 0.0f;
			}
		//M_GRID_RELY_ON;
		
		if(HAL_get_iInvA_overCurrentFlag())
			rout_data.Value2_data.usSys_err_flag1 |= ERR_INV_A_OI_CMPSS;
		if(HAL_get_iInvB_overCurrentFlag())
			rout_data.Value2_data.usSys_err_flag1 |= ERR_INV_B_OI_CMPSS;
		if(HAL_get_iInvC_overCurrentFlag())
			rout_data.Value2_data.usSys_err_flag1 |= ERR_INV_C_OI_CMPSS;

		
		if(rout_data.Set_Para.usRun_cmd == CMD_ERR_RESET)
			{
		    rout_data.Set_Para.usRun_cmd = 0;
			HAL_clearAllFaultFlags();
			RESET_ERR_MICRO;
			}
		else if(rout_data.Set_Para.usRun_cmd == CMD_WARING_RESET)
			{
			rout_data.Value2_data.usSys_warming_flag = 0;
			rout_data.Set_Para.usRun_cmd = 0;
			}

/*		if((rout_data.Set_Para.usRun_stop == DEVICE_RUN)&&(!rout_data.Value2_data.usSys_err_flag1))
			{
			rout_data.Value2_data.usRun_mode_states = DEVICE_RUN;
			}
		else
			{
			rout_data.Set_Para.usRun_stop = DEVICE_STOP;
			}*/
		
		switch(rout_data.Value2_data.usRun_mode_states)
			{
			case DEVICE_ILDE://״ָֻ̬
				if(rout_data.Set_Para.usRun_stop == CTL_RUN)//
					{
					//RESET_ERR_MICRO;
					rout_data.Value2_data.usRun_mode_states = DEVICE_START;
					}
				if(rout_data.Set_Para.usRun_cmd == CMD_DEBUG_MODE)
					{
					rout_data.Value2_data.usRun_mode_states = DEVICE_DEBUG_MODE;
					}

				usStopCount = 0;
				usTaskCount = 0;

				rout_data.Set_Para.sAc_reactivePower_set = 0;	//ÿǰ޹0
				break;
			
			case DEVICE_START:
					/*if(rout_data.Value2_data.usCharge_states == CHARGE_DIS)
						{
						//DC_RELY_HC_ON;	
						}
					else if(rout_data.Value2_data.usCharge_states == CHARGE_EN)
						{						
						M_GRID_RELY_ON;
						}*/
					if(rout_data.Set_Para.usRun_mode != DISCHARGE_OFF)
						M_GRID_RELY_ON;
					
					if(usTaskCount++ > 50)
						{
						rout_data.Value2_data.usRun_mode_states = DEVICE_CHARGING;
						usTaskCount = 0;
						}
									
				break;
			case DEVICE_CHARGING://׼磬糬ʱ			
				if(rout_data.Value2_data.usCharge_states == CHARGE_DIS)
					{					
					if(rout_data.Value1_data.fDc_voltage_avg > 10.0f)	// ʱر
						{
						DC_RELY_HC_ON;
						if(rout_data.Value1_data.fDCbus_sum_voltage > rout_data.Value1_data.fDc_voltage_avg * 0.9f)
							{
							if(usTaskCount > 150)	//150->3s
								{
								rout_data.Value2_data.usRun_mode_states = DEVICE_CHARGED;
								usTaskCount = 0;
								}
							}
						}
					}
				else if(rout_data.Value2_data.usCharge_states == CHARGE_EN)
					{
					if(rout_data.Value1_data.fGrid_voltage_A > 10.0f)	
						{
						M_FPC_RELY_HC_ON;
						//if(rout_data.Value1_data.fDCbus_sum_voltage > rout_data.Value1_data.fGrid_voltage_A * 1.414f*1.8f)
							{
							if(usTaskCount > 150)	//150->3s
								{
								rout_data.Value2_data.usRun_mode_states = DEVICE_CHARGED;
								usTaskCount = 0;
								}
							}
						}
					}
				
				if(usTaskCount++ > PFC_CHANGE_TIMER)
					{
					usTaskCount = 0;
					rout_data.Value2_data.usRun_mode_states = DEVICE_GENERAL_ERR;
					rout_data.Value2_data.usSys_err_flag1 |= ERR_PFC_CHANGE_FAIL;
					}
				break;
			case DEVICE_CHARGED://
				if(rout_data.Value2_data.usCharge_states == CHARGE_DIS)
					{
					DC_RELY_M_ON;
					if(usTaskCount++ >= 50)
						{
						usTaskCount = 0;
						DC_RELY_HC_OFF;
						slow_slip = 0.0f;
						if(rout_data.Value1_data.fDCbus_sum_voltage > rout_data.Value1_data.fGrid_voltage_A * 2.828f)//ֹѹ ֱֱ
							rout_data.Value2_data.usRun_mode_states = DEVICE_RUN_READY;
						else
							{
							rout_data.Value2_data.usRun_mode_states = DEVICE_GENERAL_ERR;
							rout_data.Value2_data.usSys_err_flag1 |= ERR_PFC_DISCHANGE_FAIL;
							}
						}
					}
				else if(rout_data.Value2_data.usCharge_states == CHARGE_EN)
					{
					M_FPC_RELY_M_ON;
					if(usTaskCount++ >= 50)
						{
						usTaskCount = 0;
						M_FPC_RELY_HC_OFF;
						slow_slip = 0.0f;
						rout_data.Value2_data.usRun_mode_states = DEVICE_RUN_READY;
						
						}
					}

				break;
			case DEVICE_RUN_READY://һ׶Σ㲢Ҫ󣬲ܵ
				usTaskCount++;
				if(rout_data.Value2_data.usCharge_states == CHARGE_DIS)
					{
					if(usTaskCount >= 50)
						{
						M_FPC_RELY_M_ON;
						}
					}

				else if(rout_data.Value2_data.usCharge_states == CHARGE_EN)
					{
					switch(usTaskCount)
						{
						case 50:
							DC_RELY_HC_ON;
							break;
						case 100:
							DC_RELY_M_ON;
							break;
						case 150:
							DC_RELY_HC_OFF;							
							break;
						}
					}
								
				if(usTaskCount >= 200)
					{
					usTaskCount = 0;
					usRun_first_flag = 1;
					slow_slip = 0.0f;
					rout_data.Value2_data.usRun_mode_states = DEVICE_RUN;
					usRun_stop_flag = RUNSTOP_START;				
					}
				
				break;
			case DEVICE_RUN://н׶Σܵ
				switch(usRun_stop_flag)
					{
					case RUNSTOP_START:
						//if(rout_data.Set_Para.usRun_mode == OFFGRID_AC)
						//	usRun_stop_flag = RUNSTOP_RUN;
						
						if(rout_data.Value2_data.usCharge_states == CHARGE_DIS)
							{							
							if(slow_slip < 1.0f)
								{
								slow_slip = slow_slip + SLOW_STEP;
								if(slow_slip > 1.0f) slow_slip = 1.0f;
								}
							else
								{
								slow_slip = 1.0f;
								usRun_stop_flag = RUNSTOP_RUN;
								}
							}
							
						else if(rout_data.Value2_data.usCharge_states == CHARGE_EN)
							{
							usRun_stop_flag = RUNSTOP_RUN;
							}
						
							/*if(0)
							{
							if(rout_data.Inst_data.fDCbat_voltage_inst > rout_data.Value1_data.fDCbus_sum_voltage)
								fTemp = rout_data.Inst_data.fDCbat_voltage_inst - rout_data.Value1_data.fDCbus_sum_voltage;
							else
								fTemp = rout_data.Value1_data.fDCbus_sum_voltage - rout_data.Inst_data.fDCbat_voltage_inst;		
							
							if(fTemp < 1.0f)
								usDcvoltage_syn = 1;
							else
								usDcvoltage_syn = 0;

							if(dcl_vBusRefSlewed <  rout_data.Inst_data.fDCbat_voltage_inst)	
								dcl_vBusRefSlewed +=  fBusSlew_step;

							if(usDcvoltage_syn)
								{
								usTaskCount++ ;
								switch(usTaskCount)
									{
									case 20:
										DC_RELY_HC_ON;
										break;
									case 40:
										DC_RELY_M_ON;
										break;
									case 60:
										DC_RELY_HC_OFF;
										ctl_closeGvLoop = 0;//
										break;
									}
								if(usTaskCount > 70)
									{
									if(slow_slip < 1.0f)
										{
										slow_slip = slow_slip + SLOW_STEP;
										if(slow_slip > 1.0f) slow_slip = 1.0f;
										}
									else
										{
										usTaskCount = 0;
										slow_slip = 1.0f;
										usRun_stop_flag = RUNSTOP_RUN;
										}
									}
								
								}
							else
								usTaskCount = 0;
							}*/
						break;
					case RUNSTOP_RUN:					
						/*if(rout_data.Value2_data.usCharge_states == CHARGE_EN)
							{
							if(rout_data.Value1_data.fDCbus_sum_voltage >= rout_data.Set_Para.ulDc_maxVoltage_thre)
								{
								slow_slip = 0;
								ctl_closeGvLoop = 1;//ѹ	
								dcl_vBusRefSlewed = rout_data.Set_Para.ulDc_maxVoltage_thre;
								}
							if((rout_data.Value1_data.fDCbus_sum_voltage > rout_data.Set_Para.ulDc_maxVoltage_thre * 0.9)&&(ctl_closeGvLoop == 0))
								{
								slow_slip = 0.1;
								}
							}*/
						
						if(rout_data.Set_Para.usRun_stop == CTL_STOP)
							usRun_stop_flag = RUNSTOP_STOP;
						break;
					case RUNSTOP_STOP:
						{
						if(slow_slip >= SLOW_STEP)
							slow_slip = slow_slip - SLOW_STEP;
						else
							{
							slow_slip = 0.0f;
							usRun_stop_flag = RUNSTOP_IDLE;
							rout_data.Value2_data.usRun_mode_states = DEVICE_RUN_OVER;
							usTaskCount = 0;
							}
						}
						break;
					}
				break;
			case DEVICE_RUN_OVER://׼ػ׶Σŵ׶
				usRun_stop_flag = RUNSTOP_IDLE;
				rout_data.Value2_data.usRun_mode_states = DEVICE_STOP;
				CONF_disablePWM();
				usStopCount = 0;
				break;
			case DEVICE_STOP:
					usStopCount++;
					switch(usStopCount)
						{
						case 50:
						//	DC_RELY_HC_ON;
						//	M_FPC_RELY_HC_ON;
							break;
						case 100:
						//	DC_RELY_M_OFF;
						//	M_FPC_RELY_M_OFF;
							break;
						case 150:
						//	M_GRID_RELY_OFF;
							break;
						case 200:
						//	M_FPC_RELY_HC_OFF;
							break;
						case 250:
						//	DC_RELY_HC_OFF;
							usStopCount = 0;
							rout_data.Value2_data.usRun_mode_states = DEVICE_ILDE;
							break;
						}
				break;
			
			case DEVICE_GENERAL_ERR://жѽзⲨ˴жϿ̵
				CONF_disablePWM();
				M_GRID_RELY_OFF;
				M_FPC_RELY_M_OFF;
				M_FPC_RELY_HC_OFF;
				DC_RELY_M_OFF;
				DC_RELY_HC_OFF;
				usTaskCount = 0;
				usRun_stop_flag = RUNSTOP_IDLE;
				rout_data.Value2_data.usRun_mode_states = DEVICE_ILDE;
				
				break;
			case DEVICE_SERIOUS_ERR://жѽзⲨ˴жϿ̵òܸλ״̬
				CONF_disablePWM();
				M_GRID_RELY_OFF;
				M_FPC_RELY_M_OFF;
				M_FPC_RELY_HC_OFF;
				DC_RELY_M_OFF;
				DC_RELY_HC_OFF;
				usTaskCount = 0;
				usRun_stop_flag = RUNSTOP_IDLE;
				break;
			case DEVICE_DEBUG_MODE:	//ģʽ IO PWM
				if(rout_data.Set_Para.usRun_cmd == CMD_DEBUG_MODE)
					{
					if((rout_data.Set_Para.usRun_cmd_data2&0x01) == 0x01)
						{M_GRID_RELY_ON;}
					else
						{M_GRID_RELY_OFF;}

					if((rout_data.Set_Para.usRun_cmd_data2&0x02) == 0x02)
						{M_FPC_RELY_M_ON;}
					else
						{M_FPC_RELY_M_OFF;}

					if((rout_data.Set_Para.usRun_cmd_data2&0x04) == 0x04)
						{M_FPC_RELY_HC_ON;}
					else
						{M_FPC_RELY_HC_OFF;}
					
					if((rout_data.Set_Para.usRun_cmd_data2&0x08) == 0x08)
						{DC_RELY_M_ON;}
					else
						{DC_RELY_M_OFF;}

					if((rout_data.Set_Para.usRun_cmd_data2&0x10) == 0x10)
						{DC_RELY_HC_ON;}
					else
						{DC_RELY_HC_OFF;}

					if(rout_data.Set_Para.usRun_cmd_data1 == 100)
						{
						
						CONF_HAL_updatePWMDuty(0.2f,0.5f,0.8f);
						CONF_enablePWM();
						}
					else if(rout_data.Set_Para.usRun_cmd_data1 == 200)
						{
						
						CONF_HAL_updatePWMDuty(-0.2f,-0.5f,-0.8f);
						CONF_enablePWM();
						}
					else
						{
						CONF_HAL_updatePWMDuty(0.0f,0.0f,0.0f);
						CONF_disablePWM();
						}
					}
				else
					{
					CONF_HAL_updatePWMDuty(0.0f,0.0f,0.0f);
					CONF_disablePWM();
					rout_data.Value2_data.usRun_mode_states = DEVICE_ILDE;
					M_GRID_RELY_OFF;
					M_FPC_RELY_M_OFF;
					M_FPC_RELY_HC_OFF;
					DC_RELY_M_OFF;
					DC_RELY_HC_OFF;
					}
				break;
			default:
				break;
		}
		
    }
}

void vsysManageTaskInit(void)
{
    
    xTaskCreateStatic(vsysManageTask,         // Function that implements the task.
                      "Sys manage task",      // Text name for the task.
                      STACK_SIZE,           // Number of indexes in the xStack array.
                      ( void * ) NULL,      // Parameter passed into the task.
                      tskIDLE_PRIORITY + 3, // Priority at which the task is created.
                      sysManageTaskStack,        // Array to use as the task's stack.
                      &sysManageTaskBuffer );    // Variable to hold the task's data structure.

}




