#include "adc_device.h"
#include "pwm_device.h"
#include "sysclock_device.h"

void HAL_setupCMPSS(uint32_t base1,
                     float32_t current_limit,
                     float32_t current_max_sense)
{
    //
    // Enable CMPSS1
    //
    CMPSS_enableModule(base1);

    //
    // Use VDDA as the reference for comparator DACs
    //
    CMPSS_configDAC(base1,
                    CMPSS_DACVAL_SYSCLK |
                    CMPSS_DACREF_VDDA |
                    CMPSS_DACSRC_SHDW);

    //
    // Set DAC to H~75% and L ~25% values
    //
    CMPSS_setDACValueHigh(base1, 2048 + (int16_t)current_limit); 
    CMPSS_setDACValueLow(base1, 2048 - (int16_t)current_limit); 

    //
    // Make sure the asynchronous path compare high and low event
    // does not go to the OR gate with latched digital filter output
    // hence no additional parameter CMPSS_OR_ASYNC_OUT_W_FILT  is passed
    // comparator oputput is "not" inverted for high compare event
    //
    CMPSS_configHighComparator(base1, CMPSS_INSRC_DAC);

    //
    // Comparator output is inverted for for low compare event
    //
    CMPSS_configLowComparator(base1, CMPSS_INSRC_DAC | CMPSS_INV_INVERTED);

    CMPSS_configFilterHigh(base1, 1, 2, 2); //10 to 30; 7 to 20
    CMPSS_configFilterLow(base1, 1, 2, 2);

    //
    // Reset filter logic & start filtering
    //
    CMPSS_initFilterHigh(base1);
    CMPSS_initFilterLow(base1);

    //
    // Configure CTRIPOUT path
    //
    CMPSS_configOutputsHigh(base1, CMPSS_TRIP_FILTER | CMPSS_TRIP_FILTER);
    CMPSS_configOutputsLow(base1, CMPSS_TRIP_FILTER | CMPSS_TRIP_FILTER);

    //
    // Comparator hysteresis control , set to 2x typical value
    //
    CMPSS_setHysteresis(base1, 2);

    //
    // Clear the latched comparator events
    //
    CMPSS_clearFilterLatchHigh(base1);
    CMPSS_clearFilterLatchLow(base1);
}


void HAL_setupADC(void)
{
	SysCtl_enablePeripheral(SYSCTL_PERIPH_CLK_ADCA);
	SysCtl_enablePeripheral(SYSCTL_PERIPH_CLK_ADCB);
	SysCtl_enablePeripheral(SYSCTL_PERIPH_CLK_ADCC);
	SysCtl_enablePeripheral(SYSCTL_PERIPH_CLK_ADCD);
	
    //ADC_setVREF(ADCA_BASE, ADC_REFERENCE_INTERNAL, ADC_REFERENCE_3_3V);
    //ADC_setVREF(ADCB_BASE, ADC_REFERENCE_INTERNAL, ADC_REFERENCE_3_3V);
    //ADC_setVREF(ADCC_BASE, ADC_REFERENCE_INTERNAL, ADC_REFERENCE_3_3V);
    //
    // set ADCCLK divider to /4
    //
	ADC_setPrescaler(ADCA_BASE, ADC_CLK_DIV_4_0);
    //ADC_setMode(ADCA_BASE, ADC_RESOLUTION_12BIT, ADC_MODE_SINGLE_ENDED);

    //
    // Set pulse positions to late
    //
    ADC_setInterruptPulseMode(ADCA_BASE, ADC_PULSE_END_OF_CONV);

    //
    // power up the ADC
    //
    ADC_enableConverter(ADCA_BASE);

    //
    // write configurations for ADC-B
    //set ADCCLK divider to / 4
    //
    ADC_setPrescaler(ADCB_BASE, ADC_CLK_DIV_4_0);
    //ADC_setMode(ADCB_BASE, ADC_RESOLUTION_12BIT, ADC_MODE_SINGLE_ENDED);

    //
    // Set pulse positions to late
    //
    ADC_setInterruptPulseMode(ADCB_BASE, ADC_PULSE_END_OF_CONV);

    //
    // power up the ADC
    //
    ADC_enableConverter(ADCB_BASE);

    //
    // write configurations for ADC-C
    // External REFERENCE must be provided
    //
    ADC_setPrescaler(ADCC_BASE, ADC_CLK_DIV_4_0);
    //ADC_setMode(ADCC_BASE, ADC_RESOLUTION_12BIT, ADC_MODE_SINGLE_ENDED);

    //
    // Set pulse positions to late
    //
    ADC_setInterruptPulseMode(ADCC_BASE, ADC_PULSE_END_OF_CONV);

    //
    // power up the ADC
    //
    ADC_enableConverter(ADCC_BASE);

    //
    // write configurations for ADC-D
    // External REFERENCE must be provided
    //
    ADC_setPrescaler(ADCD_BASE, ADC_CLK_DIV_2_0);
    //ADC_setMode(ADCD_BASE, ADC_RESOLUTION_12BIT, ADC_MODE_SINGLE_ENDED);

    //
    // Set pulse positions to late
    //
    ADC_setInterruptPulseMode(ADCD_BASE, ADC_PULSE_END_OF_CONV);

    //
    // power up the ADC
    //
    ADC_enableConverter(ADCD_BASE);



    DEVICE_DELAY_US(1000);

	ADC_setupSOC(CONF_VINV_A_ADC_BASE,
                 CONF_VINV_A_ADC_SOC_NO,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_VINV_A_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);
	
	ADC_setupSOC(CONF_VINV_B_ADC_BASE,
                 CONF_VINV_B_ADC_SOC_NO,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_VINV_B_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);

	ADC_setupSOC(CONF_VINV_C_ADC_BASE,
                 CONF_VINV_C_ADC_SOC_NO,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_VINV_C_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);

	ADC_setupSOC(CONF_IINV_MA_ADC_BASE,
                 CONF_IINV_MA_ADC_SOC_NO,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_IINV_MA_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);

	ADC_setupSOC(CONF_IINV_MB_ADC_BASE,
                 CONF_IINV_MB_ADC_SOC_NO,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_IINV_MB_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);

	ADC_setupSOC(CONF_IINV_MC_ADC_BASE,
                 CONF_IINV_MC_ADC_SOC_NO,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_IINV_MC_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);

	ADC_setupSOC(CONF_IINV_FA_ADC_BASE,
                 CONF_IINV_FA_ADC_SOC_NO,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_IINV_FA_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);

	ADC_setupSOC(CONF_IINV_FB_ADC_BASE,
                 CONF_IINV_FB_ADC_SOC_NO,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_IINV_FB_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);

	ADC_setupSOC(CONF_IINV_FC_ADC_BASE,
                 CONF_IINV_FC_ADC_SOC_NO,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_IINV_FC_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);	

	ADC_setupSOC(CONF_IGRID_A_ADC_BASE,
                 CONF_IGRID_A_ADC_SOC_NO,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_IGRID_A_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);

	ADC_setupSOC(CONF_IGRID_B_ADC_BASE,
                 CONF_IGRID_B_ADC_SOC_NO,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_IGRID_B_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);
	
	ADC_setupSOC(CONF_IGRID_C_ADC_BASE,
                 CONF_IGRID_C_ADC_SOC_NO,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_IGRID_C_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);	

	ADC_setupSOC(CONF_U88CS_ADC_BASE,
                 CONF_U88CS_ADC_SOC_NO,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_U88CS_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);

	ADC_setupSOC(CONF_U87CS_ADC_BASE,
                 CONF_U87CS_ADC_SOC_NO,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_U87CS_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);
				 
	ADC_setupSOC(CONF_VBUS_ADC_BASE,
				 CONF_VBUS_ADC_SOC_NO,
				 CONF_ADC_PWM_TRIG_SOURCE,
				 CONF_VBUS_ADC_PIN,
				 CONF_ACQPS_SYS_CLKS);



/*	ADC_setupSOC(CONF_U88CS_ADC_BASE,
                 ADC_SOC_NUMBER5,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_U88CS_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);

	ADC_setupSOC(CONF_U87CS_ADC_BASE,
                 ADC_SOC_NUMBER5,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_U87CS_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);
	
	ADC_setupSOC(CONF_VBUS_ADC_BASE,
                 ADC_SOC_NUMBER5,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_VBUS_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);*/


	//ADC-C
	ADC_setupSOC(CONF_U43CS_ADC_BASE,
                 CONF_U43CS_ADC_SOC_NO,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_U43CS_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);

	ADC_setupSOC(CONF_TEMP_ADC_BASE,
                 CONF_TEMP_ADC_SOC_NO,
                 CONF_ADC_PWM_TRIG_SOURCE,
                 CONF_TEMP_ADC_PIN,
                 CONF_ACQPS_SYS_CLKS);
				 
}


void HAL_setupBoardProtection(void)
{
	SysCtl_enablePeripheral(SYSCTL_PERIPH_CLK_CMPSS2);
	SysCtl_enablePeripheral(SYSCTL_PERIPH_CLK_CMPSS4);
	SysCtl_enablePeripheral(SYSCTL_PERIPH_CLK_CMPSS8);
    //
    // Disable all the muxes first
    //
    XBAR_disableEPWMMux(XBAR_TRIP4, 0xFF);



    HAL_setupCMPSS(CONF_IINV_MA_CMPSS_BASE,
                        CONF_IINV_TRIP_LIMIT_AMPS,
                        CONF_IINV_MAX_SENSE_AMPS);

    XBAR_setEPWMMuxConfig(XBAR_TRIP4, CONF_IINV_MA_XBAR_MUX_VAL);

    XBAR_enableEPWMMux(XBAR_TRIP4, CONF_IINV_MA_XBAR_MUX);

    XBAR_clearInputFlag(CONF_IINV_MA_XBAR_FLAG1);
    XBAR_clearInputFlag(CONF_IINV_MA_XBAR_FLAG2);





    HAL_setupCMPSS(CONF_IINV_MB_CMPSS_BASE,
                        CONF_IINV_TRIP_LIMIT_AMPS,
                        CONF_IINV_MAX_SENSE_AMPS);

    XBAR_setEPWMMuxConfig(XBAR_TRIP4, CONF_IINV_MB_XBAR_MUX_VAL);

    XBAR_enableEPWMMux(XBAR_TRIP4, CONF_IINV_MB_XBAR_MUX);

    XBAR_clearInputFlag(CONF_IINV_MB_XBAR_FLAG1);
    XBAR_clearInputFlag(CONF_IINV_MB_XBAR_FLAG2);



    HAL_setupCMPSS(CONF_IINV_MC_CMPSS_BASE,
                        CONF_IINV_TRIP_LIMIT_AMPS,
                        CONF_IINV_MAX_SENSE_AMPS);

    XBAR_setEPWMMuxConfig(XBAR_TRIP4, CONF_IINV_MC_XBAR_MUX_VAL);

    XBAR_enableEPWMMux(XBAR_TRIP4, CONF_IINV_MC_XBAR_MUX);

    XBAR_clearInputFlag(CONF_IINV_MC_XBAR_FLAG1);
    XBAR_clearInputFlag(CONF_IINV_MC_XBAR_FLAG2);

	#if CONF_PROTECTION == CONF_PROTECTION_ENABLED

    HAL_setupPWMforTrip(CONF_Q1_Q3_A_PWM_BASE);
    HAL_setupPWMforTrip(CONF_Q2_Q4_A_PWM_BASE);
    HAL_setupPWMforTrip(CONF_Q1_Q3_B_PWM_BASE);
    HAL_setupPWMforTrip(CONF_Q2_Q4_B_PWM_BASE);
    HAL_setupPWMforTrip(CONF_Q1_Q3_C_PWM_BASE);
    HAL_setupPWMforTrip(CONF_Q2_Q4_C_PWM_BASE);

	#endif
}
//===========================================================================
// End of file.
//===========================================================================
