/*
 * led.h
 *
 *  Created on: 2023122
 *      Author: QA
 */

#ifndef DEVICE_LED_H_
#define DEVICE_LED_H_

#include "driverlib.h"

//*****************************************************************************
//
// Defines for pin numbers and other GPIO configuration
//
//*****************************************************************************
//
// LEDs
//

#define DEVICE_GPIO_PIN_LED1        43U  // GPIO number for LD1
#define DEVICE_GPIO_PIN_LED2        28U  // GPIO number for LD2
//#define DEVICE_GPIO_PIN_LED3        93U  // GPIO number for LD3
#define DEVICE_GPIO_CFG_LED1        GPIO_43_GPIO43  // "pinConfig" for LD1
#define DEVICE_GPIO_CFG_LED2        GPIO_28_GPIO28  // "pinConfig" for LD2
//#define DEVICE_GPIO_CFG_LED3        GPIO_93_GPIO93  // "pinConfig" for LD3

//#define   LED2  GpioDataRegs.GPCDAT.bit.GPIO91
//#define   LED3  GpioDataRegs.GPCDAT.bit.GPIO93

//*****************************************************************************
static inline void
vGPIOSetPin(uint32_t pin)
{
    volatile uint32_t *gpioDataReg;
    uint32_t pinMask;

    //
    // Check the arguments.
    //
    ASSERT(GPIO_isPinValid(pin));

    gpioDataReg = (uint32_t *)((uintptr_t)GPIODATA_BASE) +
                  ((pin / 32U) * GPIO_DATA_REGS_STEP);

    pinMask = (uint32_t)1U << (pin % 32U);

    gpioDataReg[GPIO_GPxSET_INDEX] = pinMask;
}

//*****************************************************************************
static inline void
vGPIOClearPin(uint32_t pin)
{
    volatile uint32_t *gpioDataReg;
    uint32_t pinMask;

    //
    // Check the arguments.
    //
    ASSERT(GPIO_isPinValid(pin));

    gpioDataReg = (uint32_t *)((uintptr_t)GPIODATA_BASE) +
                  ((pin / 32U) * GPIO_DATA_REGS_STEP);

    pinMask = (uint32_t)1U << (pin % 32U);

    gpioDataReg[GPIO_GPxCLEAR_INDEX] = pinMask;
}

//*****************************************************************************
static inline void
vLED1TurnOff(void)
{
    vGPIOClearPin(DEVICE_GPIO_PIN_LED1);
}

static inline void
vLED1TurnOn(void)
{
    vGPIOSetPin(DEVICE_GPIO_PIN_LED1);
}

static inline void
vLED2TurnOff(void)
{
    vGPIOClearPin(DEVICE_GPIO_PIN_LED2);
}
static inline void
vLED2TurnOn(void)
{
    vGPIOSetPin(DEVICE_GPIO_PIN_LED2);
}
/*
static inline void
vLED3TurnOn(void)
{
    vGPIOClearPin(DEVICE_GPIO_PIN_LED3);
}
static inline void
vLED3TurnOff(void)
{
    vGPIOSetPin(DEVICE_GPIO_PIN_LED3);
}*/

static inline void
vGPIO_togglePortPins(uint32_t pin)
{
    volatile uint32_t *gpioDataReg;
    uint32_t pinMask;
    //
    // Get the starting address of the pin's registers and write to TOGGLE.
    //
    gpioDataReg = (uint32_t *)((uintptr_t)GPIODATA_BASE) +
                      ((pin / 32U) * GPIO_DATA_REGS_STEP);
    pinMask = (uint32_t)1U << (pin % 32U);

    gpioDataReg[GPIO_GPxTOGGLE_INDEX] = pinMask;
}

static inline void
vToggleLED1(void)
{
    vGPIO_togglePortPins(DEVICE_GPIO_PIN_LED1);
}

static inline void
vToggleLED2(void)
{
    vGPIO_togglePortPins(DEVICE_GPIO_PIN_LED2);
}
/*
static inline void
vToggleLED3(void)
{
    vGPIO_togglePortPins(DEVICE_GPIO_PIN_LED3);
}*/



void vLedDeviceInit(void);


#endif /* DEVICE_LED_H_ */
