#include "pwm_device.h"
#include "adc_device.h"


//
// disablePWMCLKCounting
//
void HAL_disablePWMClkCounting(void)
{
    SysCtl_disablePeripheral(SYSCTL_PERIPH_CLK_TBCLKSYNC);
}

//
// enablePWMCLKCounting
//
void HAL_enablePWMClkCounting(void)
{
    SysCtl_enablePeripheral(SYSCTL_PERIPH_CLK_TBCLKSYNC);
}

void HAL_setupPWMinUpDownCountComplimentaryMode(uint32_t base,
                          uint16_t pwm_period_ticks,
                          uint16_t pwm_dbred_ticks,
                          uint16_t pwm_dbfed_ticks)
{
    //
    // Time Base SubModule Registers
    //
    EPWM_setPeriodLoadMode(base, EPWM_PERIOD_SHADOW_LOAD);
    EPWM_setTimeBasePeriod(base, pwm_period_ticks >> 1);
    EPWM_setTimeBaseCounter(base, 0);
    EPWM_setPhaseShift(base, 0);
    EPWM_setTimeBaseCounterMode(base, EPWM_COUNTER_MODE_UP_DOWN);
    EPWM_setClockPrescaler(base, EPWM_CLOCK_DIVIDER_1,
                           EPWM_HSCLOCK_DIVIDER_1);

    //
    // Counter Compare Submodule Registers
    //
    EPWM_setCounterCompareValue(base, EPWM_COUNTER_COMPARE_A, 0);
    EPWM_setCounterCompareShadowLoadMode(base, EPWM_COUNTER_COMPARE_A,
                                         EPWM_COMP_LOAD_ON_CNTR_ZERO_PERIOD);

    //
    // Action Qualifier SubModule Registers
    //
    EPWM_setActionQualifierAction(base,
                                  EPWM_AQ_OUTPUT_A,
                                  EPWM_AQ_OUTPUT_HIGH,
                                  EPWM_AQ_OUTPUT_ON_TIMEBASE_DOWN_CMPA);
    EPWM_setActionQualifierAction(base,
                                  EPWM_AQ_OUTPUT_A,
                                  EPWM_AQ_OUTPUT_LOW,
                                  EPWM_AQ_OUTPUT_ON_TIMEBASE_UP_CMPA);

    EPWM_setActionQualifierContSWForceShadowMode(base,
                                EPWM_AQ_SW_SH_LOAD_ON_CNTR_ZERO_PERIOD);

    //
    // Active high complementary PWMs - Set up the deadband
    //

    EPWM_setDeadBandControlShadowLoadMode(base,
                                         EPWM_DB_LOAD_ON_CNTR_ZERO);

    EPWM_setRisingEdgeDelayCountShadowLoadMode(base,
                                       EPWM_RED_LOAD_ON_CNTR_PERIOD);

    EPWM_setFallingEdgeDelayCountShadowLoadMode(base,
                                       EPWM_FED_LOAD_ON_CNTR_ZERO);
    EPWM_setDeadBandCounterClock(base, EPWM_DB_COUNTER_CLOCK_FULL_CYCLE);
    EPWM_setRisingEdgeDelayCount(base, pwm_dbred_ticks);
    EPWM_setFallingEdgeDelayCount(base, pwm_dbfed_ticks);
    //EPWM_setDeadBandDelayMode(base, EPWM_DB_RED, 1);
    //EPWM_setDeadBandDelayMode(base, EPWM_DB_FED, 1);
	EPWM_setDeadBandDelayMode(base, EPWM_DB_RED, 0);
	EPWM_setDeadBandDelayMode(base, EPWM_DB_FED, 0);
    EPWM_setRisingEdgeDeadBandDelayInput(base, EPWM_DB_INPUT_EPWMA);
    EPWM_setFallingEdgeDeadBandDelayInput(base, EPWM_DB_INPUT_EPWMA);
    EPWM_setDeadBandDelayPolarity(base, EPWM_DB_FED,
                                  EPWM_DB_POLARITY_ACTIVE_LOW);
    EPWM_setDeadBandDelayPolarity(base, EPWM_DB_RED,
                                  EPWM_DB_POLARITY_ACTIVE_HIGH);	
}


void HAL_enablePWMCLK(void)

{
	SysCtl_enablePeripheral(CONF_Q1_Q3_MA_PWM_CLKE);
	SysCtl_enablePeripheral(CONF_Q2_Q4_MA_PWM_CLKE);
	SysCtl_enablePeripheral(CONF_Q1_Q3_MB_PWM_CLKE);
	SysCtl_enablePeripheral(CONF_Q2_Q4_MB_PWM_CLKE);
	SysCtl_enablePeripheral(CONF_Q1_Q3_MC_PWM_CLKE);
	SysCtl_enablePeripheral(CONF_Q2_Q4_MC_PWM_CLKE);
}


void HAL_setupPWM(void)
{
	

    HAL_setupPWMinUpDownCountComplimentaryMode(CONF_Q1_Q3_A_PWM_BASE,
                               CONF_PWM_PERIOD_TICKS,
                               CONF_PWM_DEADBAND_TICKS,
                               CONF_PWM_DEADBAND_TICKS);
                              

    HAL_setupPWMinUpDownCountComplimentaryMode(CONF_Q2_Q4_A_PWM_BASE,
                               CONF_PWM_PERIOD_TICKS,
                               CONF_PWM_DEADBAND_TICKS ,
                               CONF_PWM_DEADBAND_TICKS);
                               

    HAL_setupPWMinUpDownCountComplimentaryMode(CONF_Q1_Q3_B_PWM_BASE,
                               CONF_PWM_PERIOD_TICKS,
                               CONF_PWM_DEADBAND_TICKS ,
                               CONF_PWM_DEADBAND_TICKS);
                              
    HAL_setupPWMinUpDownCountComplimentaryMode(CONF_Q2_Q4_B_PWM_BASE,
                               CONF_PWM_PERIOD_TICKS,
                               CONF_PWM_DEADBAND_TICKS ,
                               CONF_PWM_DEADBAND_TICKS);
                               
    HAL_setupPWMinUpDownCountComplimentaryMode(CONF_Q1_Q3_C_PWM_BASE,
                               CONF_PWM_PERIOD_TICKS,
                               CONF_PWM_DEADBAND_TICKS ,
                               CONF_PWM_DEADBAND_TICKS);
                               

    HAL_setupPWMinUpDownCountComplimentaryMode(CONF_Q2_Q4_C_PWM_BASE,
                               CONF_PWM_PERIOD_TICKS,
                               CONF_PWM_DEADBAND_TICKS ,
                               CONF_PWM_DEADBAND_TICKS);
                               
    //
    // configure PWM 1 as master and Phase 2 as slaves and
    // let it pass the sync in pulse from PWM1
    //
    EPWM_disablePhaseShiftLoad(CONF_Q1_Q3_A_PWM_BASE);
    EPWM_setSyncOutPulseMode(CONF_Q1_Q3_A_PWM_BASE,
                             EPWM_SYNC_OUT_PULSE_ON_COUNTER_ZERO);

    EPWM_enablePhaseShiftLoad(CONF_Q2_Q4_A_PWM_BASE);
    EPWM_setSyncOutPulseMode(CONF_Q2_Q4_A_PWM_BASE,
                             EPWM_SYNC_OUT_PULSE_ON_SOFTWARE);
    EPWM_setPhaseShift(CONF_Q2_Q4_A_PWM_BASE, 2);
    EPWM_setCountModeAfterSync(CONF_Q2_Q4_A_PWM_BASE,
                               EPWM_COUNT_MODE_UP_AFTER_SYNC);

    EPWM_enablePhaseShiftLoad(CONF_Q1_Q3_B_PWM_BASE);
    EPWM_setSyncOutPulseMode(CONF_Q1_Q3_B_PWM_BASE,
                             EPWM_SYNC_OUT_PULSE_ON_SOFTWARE);
    EPWM_setPhaseShift(CONF_Q1_Q3_B_PWM_BASE, 2);
    EPWM_setCountModeAfterSync(CONF_Q1_Q3_B_PWM_BASE,
                               EPWM_COUNT_MODE_UP_AFTER_SYNC);

    EPWM_enablePhaseShiftLoad(CONF_Q2_Q4_B_PWM_BASE);
    EPWM_setSyncOutPulseMode(CONF_Q2_Q4_B_PWM_BASE,
                             EPWM_SYNC_OUT_PULSE_ON_SOFTWARE);
    EPWM_setPhaseShift(CONF_Q2_Q4_B_PWM_BASE, 2);
    EPWM_setCountModeAfterSync(CONF_Q2_Q4_B_PWM_BASE,
                               EPWM_COUNT_MODE_UP_AFTER_SYNC);

    EPWM_enablePhaseShiftLoad(CONF_Q1_Q3_C_PWM_BASE);
    EPWM_setSyncOutPulseMode(CONF_Q1_Q3_C_PWM_BASE,
                             EPWM_SYNC_OUT_PULSE_ON_SOFTWARE);
    EPWM_setPhaseShift(CONF_Q1_Q3_C_PWM_BASE, 2);
    EPWM_setCountModeAfterSync(CONF_Q1_Q3_C_PWM_BASE,
                               EPWM_COUNT_MODE_UP_AFTER_SYNC);

    EPWM_enablePhaseShiftLoad(CONF_Q2_Q4_C_PWM_BASE);
    EPWM_setSyncOutPulseMode(CONF_Q2_Q4_C_PWM_BASE,
                             EPWM_SYNC_OUT_PULSE_ON_SOFTWARE);
    EPWM_setPhaseShift(CONF_Q2_Q4_C_PWM_BASE, 2);
    EPWM_setCountModeAfterSync(CONF_Q2_Q4_C_PWM_BASE,
                               EPWM_COUNT_MODE_UP_AFTER_SYNC);
}


//
// setupEPWMtoTriggerADCSOC(uint32_t base)
//
void HAL_setupTriggerForADC(uint32_t base)
{
    //
    // Select SOC from counter at ctr = CMPBD
    //
    EPWM_setADCTriggerSource(base, EPWM_SOC_A, EPWM_SOC_TBCTR_U_CMPB );

    //
    // write value to CMPB
    //
    EPWM_setCounterCompareValue(base, EPWM_COUNTER_COMPARE_B,(uint16_t)2000);

	
  //         ((uint16_t)((float32_t)CONF_PWM_PERIOD_TICKS * (float32_t)0.5)
  //         - (uint16_t)( (float32_t) CONF_ACQPS_SYS_CLKS * (float32_t)6.0
  //  * (float32_t)(PWMSYSCLOCK_FREQ_HZ / (float32_t)CPU_SYS_CLOCK_FREQ_HZ) )
  //         - (uint16_t)( (float32_t)  CONF_ADC_CONV_TIME
   //            * (float32_t) PWMSYSCLOCK_FREQ_HZ * (float32_t)6.0 ) ) );

    //
    // Generate pulse on 1st even
    //
    EPWM_setADCTriggerEventPrescale(base, EPWM_SOC_A, 1);

    //
    // Enable SOC on A group
    //
    EPWM_enableADCTrigger(base, EPWM_SOC_A);

}


//
// setPinAsPWM()
//
void HAL_setPinsAsPWM()
{
		GPIO_setDirectionMode(CONF_Q1_A_PWM_GPIO, GPIO_DIR_MODE_OUT);
		GPIO_setPadConfig(CONF_Q1_A_PWM_GPIO, GPIO_PIN_TYPE_STD);
		GPIO_setPinConfig(CONF_Q1_A_PWM_GPIO_PIN_CONFIG);
	
		GPIO_setDirectionMode(CONF_Q3_A_PWM_GPIO, GPIO_DIR_MODE_OUT);
		GPIO_setPadConfig(CONF_Q3_A_PWM_GPIO, GPIO_PIN_TYPE_STD);
		GPIO_setPinConfig(CONF_Q3_A_PWM_GPIO_PIN_CONFIG);
	
		GPIO_setDirectionMode(CONF_Q2_A_PWM_GPIO, GPIO_DIR_MODE_OUT);
		GPIO_setPadConfig(CONF_Q2_A_PWM_GPIO, GPIO_PIN_TYPE_STD);
		GPIO_setPinConfig(CONF_Q2_A_PWM_GPIO_PIN_CONFIG);
	
		GPIO_setDirectionMode(CONF_Q4_A_PWM_GPIO, GPIO_DIR_MODE_OUT);
		GPIO_setPadConfig(CONF_Q4_A_PWM_GPIO, GPIO_PIN_TYPE_STD);
		GPIO_setPinConfig(CONF_Q4_A_PWM_GPIO_PIN_CONFIG);
	
		GPIO_setDirectionMode(CONF_Q1_B_PWM_GPIO, GPIO_DIR_MODE_OUT);
		GPIO_setPadConfig(CONF_Q1_B_PWM_GPIO, GPIO_PIN_TYPE_STD);
		GPIO_setPinConfig(CONF_Q1_B_PWM_GPIO_PIN_CONFIG);
	
		GPIO_setDirectionMode(CONF_Q3_B_PWM_GPIO, GPIO_DIR_MODE_OUT);
		GPIO_setPadConfig(CONF_Q3_B_PWM_GPIO, GPIO_PIN_TYPE_STD);
		GPIO_setPinConfig(CONF_Q3_B_PWM_GPIO_PIN_CONFIG);
	
		GPIO_setDirectionMode(CONF_Q2_B_PWM_GPIO, GPIO_DIR_MODE_OUT);
		GPIO_setPadConfig(CONF_Q2_B_PWM_GPIO, GPIO_PIN_TYPE_STD);
		GPIO_setPinConfig(CONF_Q2_B_PWM_GPIO_PIN_CONFIG);
	
		GPIO_setDirectionMode(CONF_Q4_B_PWM_GPIO, GPIO_DIR_MODE_OUT);
		GPIO_setPadConfig(CONF_Q4_B_PWM_GPIO, GPIO_PIN_TYPE_STD);
		GPIO_setPinConfig(CONF_Q4_B_PWM_GPIO_PIN_CONFIG);
	
		GPIO_setDirectionMode(CONF_Q1_C_PWM_GPIO, GPIO_DIR_MODE_OUT);
		GPIO_setPadConfig(CONF_Q1_C_PWM_GPIO, GPIO_PIN_TYPE_STD);
		GPIO_setPinConfig(CONF_Q1_C_PWM_GPIO_PIN_CONFIG);
	
		GPIO_setDirectionMode(CONF_Q3_C_PWM_GPIO, GPIO_DIR_MODE_OUT);
		GPIO_setPadConfig(CONF_Q3_C_PWM_GPIO, GPIO_PIN_TYPE_STD);
		GPIO_setPinConfig(CONF_Q3_C_PWM_GPIO_PIN_CONFIG);
	
		GPIO_setDirectionMode(CONF_Q2_C_PWM_GPIO, GPIO_DIR_MODE_OUT);
		GPIO_setPadConfig(CONF_Q2_C_PWM_GPIO, GPIO_PIN_TYPE_STD);
		GPIO_setPinConfig(CONF_Q2_C_PWM_GPIO_PIN_CONFIG);
	
		GPIO_setDirectionMode(CONF_Q4_C_PWM_GPIO, GPIO_DIR_MODE_OUT);
		GPIO_setPadConfig(CONF_Q4_C_PWM_GPIO, GPIO_PIN_TYPE_STD);
		GPIO_setPinConfig(CONF_Q4_C_PWM_GPIO_PIN_CONFIG);
	
	
}





//
// enable PWM Interrupt generation
//
void HAL_enablePWMInterruptGeneration(uint32_t base,
                                                uint16_t cmpc_val)
{
    //
    // write value to CMPC
    //
    EPWM_setCounterCompareValue(base, EPWM_COUNTER_COMPARE_C,
                                cmpc_val);

    EPWM_setInterruptSource(base, EPWM_INT_TBCTR_PERIOD);//EPWM_INT_TBCTR_ZERO   EPWM_INT_TBCTR_D_CMPC  EPWM_INT_TBCTR_ZERO_OR_PERIOD  EPWM_INT_TBCTR_U_CMPC
    EPWM_setInterruptEventCount(base, CNTRL_ISR_FREQ_RATIO);
    EPWM_enableInterrupt(base);
    EPWM_clearEventTriggerInterruptFlag(base);
}

//
// clearPWM Interrupt Flag
//
void HAL_clearPWMInterruptFlag(uint32_t base)
{
    EPWM_clearEventTriggerInterruptFlag(base);
}

//
// getPWM Interrupt Flag
//
bool HAL_getPWMInterruptFlag(uint32_t base)
{
    return(EPWM_getEventTriggerInterruptStatus(base));
}

//
// clearInterrupt
//
void HAL_clearInterrupt(uint16_t pie_group_no)
{
    Interrupt_clearACKGroup(pie_group_no);
}



void HAL_setupPWMforTrip(uint32_t base)
{
    //
    // Trip 4 is the input to the DCAHCOMPSEL
    //
    EPWM_selectDigitalCompareTripInput(base,
                                      EPWM_DC_TRIP_TRIPIN4,
                                      EPWM_DC_TYPE_DCAH);
    EPWM_setTripZoneDigitalCompareEventCondition(base,
                                                EPWM_TZ_DC_OUTPUT_A1,
                                                EPWM_TZ_EVENT_DCXH_HIGH);
    EPWM_setDigitalCompareEventSource(base,
                                     EPWM_DC_MODULE_A,
                                     EPWM_DC_EVENT_1,
                                     EPWM_DC_EVENT_SOURCE_ORIG_SIGNAL);
    EPWM_setDigitalCompareEventSyncMode(base,
                                       EPWM_DC_MODULE_A,
                                       EPWM_DC_EVENT_1,
                                       EPWM_DC_EVENT_INPUT_NOT_SYNCED);

    //
    // Enable the following trips - DCAEVT1
    //
    EPWM_enableTripZoneSignals(base, EPWM_TZ_SIGNAL_DCAEVT1);

    //
    // Enable the following trips - Emulator Stop
    //
    EPWM_enableTripZoneSignals(base, EPWM_TZ_SIGNAL_CBC6);


    //
    // What do we want the OST / CBC events to do?
    // TZA events can force EPWMxA
    // TZB events can force EPWMxB
    //
    EPWM_setTripZoneAction(base, EPWM_TZ_ACTION_EVENT_TZA, EPWM_TZ_ACTION_LOW);
    EPWM_setTripZoneAction(base, EPWM_TZ_ACTION_EVENT_TZB, EPWM_TZ_ACTION_LOW);

    //
    // Clear spurious emulator stop signals
    //
    EPWM_clearCycleByCycleTripZoneFlag(base, EPWM_TZ_CBC_FLAG_6);

    //
    // Clear any spurious DCAEVT1 flags
    //
    EPWM_clearTripZoneFlag(base, EPWM_TZ_FLAG_DCAEVT1);

    //
    // Force a trip on PWM to safely start the system
    //
    EPWM_forceTripZoneEvent(base, EPWM_TZ_FORCE_EVENT_OST);

}


//===========================================================================
// End of file.
//===========================================================================
