/*
 * sci_device.c
 *
 *  Created on: 2023123
 *      Author: QA
 */
#include "sys_config.h"
#include "scia_device.h"
#include "sysclock_device.h"
#include "FreeRTOS.h"
#include "task.h"

#ifdef _USE_WATCHDOG
#include "watchdog_device.h"
#endif

// Globals
#define SCIA_SEND_ST  (0x0001)  //send interrupt status
#define SCIA_RECEIVE_ST (0x0002) //receive interrupt status
#define SCIA_RECEIVE_ST_ING (0x0004) //During the process of receiving frames
static uint16_t usSciaStatus = 0;

// Send data for SCI-A
#define SCIA_TXRX_BUF_SIZE 256
static uint16_t usSciaSendData[SCIA_TXRX_BUF_SIZE];
static uint16_t usSciaSendDataLenth = 0;

// Received data for SCI-A
#define RX_BUF_NUM_MAX 3
static uint16_t usSciaRcvData[RX_BUF_NUM_MAX][SCIA_TXRX_BUF_SIZE];
static uint16_t usSciaRcvDataLenth[RX_BUF_NUM_MAX] = {0};
static uint16_t usSciaRCVInDataPtr   = 0; //ջָλ
static uint16_t usSciaRCVOutDataPrt  = 0; //ջָλ
static uint16_t usSciaRcvDataLenthxx = 0;

#define STACK_SIZE  256U
static StaticTask_t vSciaISRCoTaskBuffer;
static StackType_t  vSciaISRCoTaskStack[STACK_SIZE*2];

//SCIA Black for ISR Notify
static TaskHandle_t xSCIATaskToNotify = NULL;

//SCIA Black read write Notify
static TaskHandle_t xSCIAReadWriteTaskToNotify = NULL;
static uint16_t usSciaWriteDataBlockST = 0;  //1:give notify

//functions
__interrupt void vSciaTXFIFOISR(void);
__interrupt void vSciaRXFIFOISR(void);
void vSciaInitFIFO(uint32_t ulbaud);

//Write data to SCIA
//return: -1 fault ; 0 done
int16_t sSciaWrite(uint16_t *dt, uint16_t lenth)
{
    uint16_t i;
    int16_t rtn = 0;

    if(usSciaSendDataLenth == 0)
    {
        usSciaSendDataLenth = lenth;
        for(i=0; i < usSciaSendDataLenth; i++ )
            usSciaSendData[i] = dt[i];

        //start send
        HWREGH(SCIA_BASE + SCI_O_FFTX) |= SCI_FFTX_TXFFIENA;
    }
    else
    {
        rtn = -1;
    }

    return rtn;
}

//Read data to SCIA
//return: recieve data lenth
uint16_t usSciaRead(uint16_t *buf)
{
    uint16_t i;
    uint16_t size = 0;
    uint16_t *pusData;

    if (usSciaRCVInDataPtr == usSciaRCVOutDataPrt) //no received
    {
        size = 0;
    }
    else
    {
        size = usSciaRcvDataLenth[usSciaRCVOutDataPrt];
        pusData = usSciaRcvData[usSciaRCVOutDataPrt];

        for(i = 0; i < size; i++ )
            buf[i] = pusData[i];

        if (++usSciaRCVOutDataPrt == RX_BUF_NUM_MAX)
            usSciaRCVOutDataPrt = 0;
    }

    return size;
}

//******************Bloack Read Write SCIA*************************************
//Block Write data to SCIA
//return: -1 fault ; 0 done
int16_t sSciaBlockWrite(uint16_t *dt, uint16_t lenth, TickType_t xBlockTime)
{
    uint16_t i;
    int16_t rtn = -1;

    if(usSciaSendDataLenth > 0)
    {
        /* Store the handle of the calling task. */
        usSciaWriteDataBlockST = 1;
        xSCIAReadWriteTaskToNotify = xTaskGetCurrentTaskHandle();
        ulTaskNotifyTake( pdFALSE, xBlockTime );
    }

    if(usSciaSendDataLenth == 0)
    {
        usSciaSendDataLenth = lenth;
        for(i=0; i < usSciaSendDataLenth; i++ )
            usSciaSendData[i] = dt[i];

        //start send
        HWREGH(SCIA_BASE + SCI_O_FFTX) |= SCI_FFTX_TXFFIENA;
    }
    else
    {
        rtn = -1;
    }

    return rtn;
}

//Block Read data to SCIA
//return: recieve data lenth
uint16_t usSciaBlockRead(uint16_t *buf, TickType_t xBlockTime)
{
    uint16_t i;
    uint16_t size = 0;
    uint16_t *pusData;

     /* Store the handle of the calling task. */
    xSCIAReadWriteTaskToNotify = xTaskGetCurrentTaskHandle();

    if( ulTaskNotifyTake( pdFALSE, xBlockTime ) > 0)
    {
        if (usSciaRCVInDataPtr == usSciaRCVOutDataPrt) //no received
        {
            size = 0;
        }
        else
        {
            size = usSciaRcvDataLenth[usSciaRCVOutDataPrt];
            pusData = usSciaRcvData[usSciaRCVOutDataPrt];

            for(i = 0; i < size; i++ )
                buf[i] = pusData[i];

            if (++usSciaRCVOutDataPrt == RX_BUF_NUM_MAX)
                usSciaRCVOutDataPrt = 0;
        }
    }
    return size;
}

//-------------------------------------------------------------------------------------------------
void vSciaISRCoTask(void * pvParameters)
{
    uint16_t *pusData;
    //const TickType_t xBlockTime = pdMS_TO_TICS( 500 );
    const TickType_t xBlockTime = (20 / portTICK_PERIOD_MS);  //Block 20ms

    /* Store the handle of the calling task. */
    xSCIATaskToNotify = xTaskGetCurrentTaskHandle();

    for(;;)
    {
        uint16_t i,j;
        uint16_t send_next_flag = 0;

        #ifdef _USE_WATCHDOG
        //watchdog marsk
        uswatchdogTaskMask |= WD_TASK_MASK_SCIA;
        #endif

        if(SCI_getOverflowStatus(SCIA_BASE)) //clear fifo overflow error
        {
            SCI_performSoftwareReset(SCIA_BASE);
            SCI_clearOverflowStatus(SCIA_BASE);
            SCI_resetRxFIFO(SCIA_BASE);
            usSciaRcvDataLenthxx = 0;
        }

        if( ulTaskNotifyTake( pdFALSE, xBlockTime ) > 0)
        {
            //************** send coisr **************************
            if((usSciaStatus & SCIA_SEND_ST) == SCIA_SEND_ST)
            {
                ////////send///////
                static uint16_t usSendCnt = 0;

                send_next_flag = 1;
                i = usSciaSendDataLenth - usSendCnt;

                //send fifo buff data lenth
                j = 16 - SCI_getTxFIFOStatus(SCIA_BASE);

                if( i == 0 )
                {
                    usSendCnt = 0;
                    j = 0;
                    usSciaSendDataLenth = 0;
                    send_next_flag = 0;

                    if(usSciaWriteDataBlockST == 1)  //give write notify
                    {
                        xTaskNotifyGive( xSCIAReadWriteTaskToNotify );
                        usSciaWriteDataBlockST = 0;
                    }

                    //SCI_clearInterruptStatus(SCIA_BASE, SCI_INT_TXFF);
                    HWREGH(SCIA_BASE + SCI_O_FFTX) |= SCI_FFTX_TXFFINTCLR;
                    // Issue PIE ACK
                    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);
                }
                else if(j > i)
                {
                    j = i;
                }

                for(i = 0; i < j; i++)
                {
                    HWREGH(SCIA_BASE + SCI_O_TXBUF) = usSciaSendData[usSendCnt++];
                }

                usSciaStatus &= ~SCIA_SEND_ST;

                if(send_next_flag == 1)
                {
                    //SCI_clearInterruptStatus(SCIA_BASE, SCI_INT_TXFF);
                    HWREGH(SCIA_BASE + SCI_O_FFTX) |= SCI_FFTX_TXFFINTCLR;
                    // Issue PIE ACK
                    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);
                    //open TXFF interrupt
                    HWREGH(SCIA_BASE + SCI_O_FFTX) |= SCI_FFTX_TXFFIENA;
                }
                //////// end send /////////
            }

            //************** reciev coisr **************************
            if((usSciaStatus & SCIA_RECEIVE_ST) == SCIA_RECEIVE_ST)
            {
                ////////   reciev  ///////
                usSciaStatus |= SCIA_RECEIVE_ST_ING;

                //recieved data lenth
                j = SCI_getRxFIFOStatus(SCIA_BASE);

                pusData = usSciaRcvData[usSciaRCVInDataPtr];

                for(i = 0; i < j; i++)
                {
                    if( usSciaRcvDataLenthxx >= SCIA_TXRX_BUF_SIZE )
                    {
                        usSciaRcvDataLenthxx = 0;
                    }
                    // Return the character from the receive buffer.
                    pusData[usSciaRcvDataLenthxx++] = (uint16_t)
                                       (HWREGH(SCIA_BASE + SCI_O_RXBUF) & SCI_RXBUF_SAR_M);
                }

                ////////end reciev///////
                usSciaStatus &= ~SCIA_RECEIVE_ST;

                //SCI_clearInterruptStatus(SCIA_BASE, SCI_INT_RXFF);
                HWREGH(SCIA_BASE + SCI_O_FFRX) |= SCI_FFRX_RXFFINTCLR;
                // Issue PIE ack
                Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);
                //open RXFF interrupt
                HWREGH(SCIA_BASE + SCI_O_FFRX) |= SCI_FFRX_RXFFIENA;
            }
        }
        else
        {
            //recieved data lenth
            j = SCI_getRxFIFOStatus(SCIA_BASE);

            if(j > 0)
            {
                //receive frame end
                if( (usSciaStatus & SCIA_RECEIVE_ST_ING) == 0)
                {
                    usSciaRcvDataLenthxx = 0;
                }

                pusData = usSciaRcvData[usSciaRCVInDataPtr];

                for(i = 0; i < j; i++)
                {
                    if( usSciaRcvDataLenthxx >= SCIA_TXRX_BUF_SIZE )
                    {
                        usSciaRcvDataLenthxx = 0;
                    }
                    // Return the character from the receive buffer.
                    pusData[usSciaRcvDataLenthxx++] = (uint16_t)
                                      (HWREGH(SCIA_BASE + SCI_O_RXBUF) & SCI_RXBUF_SAR_M);
                }

                ////////end reciev///////
                usSciaStatus &= ~SCIA_RECEIVE_ST_ING;

                /* ݳ */
                usSciaRcvDataLenth[usSciaRCVInDataPtr] = usSciaRcvDataLenthxx;

                /* ׼һν */
                if (++(usSciaRCVInDataPtr) == RX_BUF_NUM_MAX) {
                    usSciaRCVInDataPtr = 0;
                }

                /* BUFǰһ */
                if (usSciaRCVInDataPtr == usSciaRCVOutDataPrt)
                {
                  if (++usSciaRCVOutDataPrt == RX_BUF_NUM_MAX)
                      usSciaRCVOutDataPrt = 0;
                }

                //one frame done
                usSciaRcvDataLenthxx = 0;

                if(xSCIAReadWriteTaskToNotify != NULL)  //Notify Read Data
                    xTaskNotifyGive( xSCIAReadWriteTaskToNotify );

                //SCI_clearInterruptStatus(SCIA_BASE, SCI_INT_RXFF);
                HWREGH(SCIA_BASE + SCI_O_FFRX) |= SCI_FFRX_RXFFINTCLR;
                // Issue PIE ack
                Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);
                //open RXFF interrupt
                HWREGH(SCIA_BASE + SCI_O_FFRX) |= SCI_FFRX_RXFFIENA;
            }
            else
            {
                if( (usSciaStatus & SCIA_RECEIVE_ST_ING) == SCIA_RECEIVE_ST_ING)
                {
                    ////////end reciev///////
                    usSciaStatus &= ~SCIA_RECEIVE_ST_ING;

                    /* ݳ */
                    usSciaRcvDataLenth[usSciaRCVInDataPtr] = usSciaRcvDataLenthxx;

                    /* ׼һν */
                    if (++(usSciaRCVInDataPtr) == RX_BUF_NUM_MAX) {
                        usSciaRCVInDataPtr = 0;
                    }

                    /* BUFǰһ */
                    if (usSciaRCVInDataPtr == usSciaRCVOutDataPrt)
                    {
                      if (++usSciaRCVOutDataPrt == RX_BUF_NUM_MAX)
                          usSciaRCVOutDataPrt = 0;
                    }

                    if(xSCIAReadWriteTaskToNotify != NULL)  //Notify Read Data
                        xTaskNotifyGive( xSCIAReadWriteTaskToNotify );

                    usSciaRcvDataLenthxx = 0;
                }
            }
            // end if( j > 0 )
        }
    }
}

//
// initSCIAFIFO - Configure SCIA FIFO
//
void vSciaInitFIFO(uint32_t ulbaud)
{
    //
    // 8 char bits, 1 stop bit, no parity. Baud rate is 9600.
    //
    SCI_setConfig(SCIA_BASE, DEVICE_LSPCLK_FREQ, ulbaud, (SCI_CONFIG_WLEN_8 |
                                                        SCI_CONFIG_STOP_ONE |
                                                        SCI_CONFIG_PAR_NONE));
    SCI_enableModule(SCIA_BASE);
    SCI_disableLoopback(SCIA_BASE);
    SCI_resetChannels(SCIA_BASE);
    SCI_enableFIFO(SCIA_BASE);

    //
    // RX and TX FIFO Interrupts Enabled
    //
    //SCI_enableInterrupt(SCIA_BASE, (SCI_INT_RXFF | SCI_INT_TXFF));
    SCI_enableInterrupt(SCIA_BASE, SCI_INT_RXFF);
    SCI_enableInterrupt(SCIA_BASE, SCI_INT_RXERR);

    SCI_setFIFOInterruptLevel(SCIA_BASE, SCI_FIFO_TX8, SCI_FIFO_RX8);
    SCI_performSoftwareReset(SCIA_BASE);

    SCI_resetTxFIFO(SCIA_BASE);
    SCI_resetRxFIFO(SCIA_BASE);

#ifdef AUTOBAUD
    //
    // Perform an autobaud lock.
    // SCI expects an 'a' or 'A' to lock the baud rate.
    //
    SCI_lockAutobaud(SCIA_BASE);
#endif
}


void vSciaDeviceInit(uint32_t ulbaud)
{
    //turn on SCIA peripherals
    SysCtl_enablePeripheral(SYSCTL_PERIPH_CLK_SCIA);

    // GPIO is the SCI Rx pin.
    GPIO_setMasterCore(DEVICE_GPIO_PIN_SCIRXDA, GPIO_CORE_CPU1);
    GPIO_setPinConfig(GPIO_85_SCIRXDA);
    GPIO_setDirectionMode(DEVICE_GPIO_PIN_SCIRXDA, GPIO_DIR_MODE_IN);
    GPIO_setPadConfig(DEVICE_GPIO_PIN_SCIRXDA, GPIO_PIN_TYPE_STD);
    GPIO_setQualificationMode(DEVICE_GPIO_PIN_SCIRXDA, GPIO_QUAL_ASYNC);

    // GPIO is the SCI Tx pin.
    GPIO_setMasterCore(DEVICE_GPIO_PIN_SCITXDA, GPIO_CORE_CPU1);
    GPIO_setPinConfig(GPIO_84_SCITXDA);
    GPIO_setDirectionMode(DEVICE_GPIO_PIN_SCITXDA, GPIO_DIR_MODE_OUT);
    GPIO_setPadConfig(DEVICE_GPIO_PIN_SCITXDA, GPIO_PIN_TYPE_STD);
    GPIO_setQualificationMode(DEVICE_GPIO_PIN_SCITXDA, GPIO_QUAL_ASYNC);

    // Interrupts that are used in this example are re-mapped to
    // ISR functions found within this file.
    Interrupt_register(INT_SCIA_RX, vSciaRXFIFOISR);
    Interrupt_register(INT_SCIA_TX, vSciaTXFIFOISR);

    // Initialize the Device Peripherals:
    vSciaInitFIFO(ulbaud);

    Interrupt_enable(INT_SCIA_RX);
    Interrupt_enable(INT_SCIA_TX);

    SCI_clearInterruptStatus(SCIA_BASE, SCI_INT_TXFF);
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);

    // Create the task without using any dynamic memory allocation.

    xTaskCreateStatic(vSciaISRCoTask,         // Function that implements the task.
                      "SCIA task",      // Text name for the task.
                      STACK_SIZE*2,           // Number of indexes in the xStack array.
                      ( void * ) NULL,      // Parameter passed into the task.
                      configMAX_PRIORITIES - 1, // Priority at which the task is created.
                      vSciaISRCoTaskStack,        // Array to use as the task's stack.
                      &vSciaISRCoTaskBuffer );    // Variable to hold the task's data structure.



}

//
// sciaTXFIFOISR - SCIA Transmit FIFO ISR
//
__interrupt void vSciaTXFIFOISR(void)
{
    BaseType_t xHigherPriorityTaskWoken;

//    //SCI_clearInterruptStatus(SCIA_BASE, SCI_INT_TXFF);
//    HWREGH(SCIA_BASE + SCI_O_FFTX) |= SCI_FFTX_TXFFINTCLR;
//
//    // Issue PIE ACK
//    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);

    //disable tx interrupt
    HWREGH(SCIA_BASE + SCI_O_FFTX) &= ~SCI_FFTX_TXFFIENA;

    //set send isr flag
    usSciaStatus |= SCIA_SEND_ST;

    //send TaskNotify to vSciaISRCoTask
    xHigherPriorityTaskWoken = pdFALSE;
    vTaskNotifyGiveFromISR( xSCIATaskToNotify, &xHigherPriorityTaskWoken );
    portYIELD_FROM_ISR( xHigherPriorityTaskWoken );
}

//
// sciaRXFIFOISR - SCIA Receive FIFO ISR
//
__interrupt void vSciaRXFIFOISR(void)
{
    BaseType_t xHigherPriorityTaskWoken;

    if((HWREGH(SCIA_BASE + SCI_O_FFRX) & SCI_FFRX_RXFFINT) == SCI_FFRX_RXFFINT)
    {
//        //SCI_clearInterruptStatus(SCIA_BASE, SCI_INT_RXFF);
//        HWREGH(SCIA_BASE + SCI_O_FFRX) |= SCI_FFRX_RXFFINTCLR;
//
//        // Issue PIE ack
//        Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);

        //close RXFF interrupt
        HWREGH(SCIA_BASE + SCI_O_FFRX) &= ~SCI_FFRX_RXFFIENA;

        //set recieved isr flag
        usSciaStatus |= SCIA_RECEIVE_ST;

        //send TaskNotify to vSciaISRCoTask
        xHigherPriorityTaskWoken = pdFALSE;
        vTaskNotifyGiveFromISR( xSCIATaskToNotify, &xHigherPriorityTaskWoken );
        portYIELD_FROM_ISR( xHigherPriorityTaskWoken );
    }
    else if( (HWREGH(SCIA_BASE + SCI_O_RXST) & (SCI_RXST_RXERROR)) == SCI_RXST_RXERROR )
    {
         SCI_performSoftwareReset(SCIA_BASE);
         SCI_resetRxFIFO(SCIA_BASE);
         usSciaRcvDataLenthxx = 0;
    }
    else if(SCI_getOverflowStatus(SCIA_BASE))
    {
        SCI_clearOverflowStatus(SCIA_BASE);
        SCI_resetRxFIFO(SCIA_BASE);
        usSciaRcvDataLenthxx = 0;
    }
}

