/*
 * scib_device.c
 *
 *  Created on: 2023123
 *      Author: QA
 */
#include "sys_config.h"
#include "scib_device.h"
#include "sysclock_device.h"
#include "FreeRTOS.h"
#include "task.h"

#ifdef _USE_WATCHDOG
#include "watchdog_device.h"
#endif

// Globals
#define SCIB_SEND_ST  (0x0001)  //send interrupt status
#define SCIB_RECEIVE_ST (0x0002) //receive interrupt status
#define SCIB_RECEIVE_ST_ING (0x0004) //During the process of receiving frames
static uint16_t usScibStatus = 0;

// Send data for SCI-B
#define SCIB_TXRX_BUF_SIZE 256
static uint16_t usScibSendData[SCIB_TXRX_BUF_SIZE];
static uint16_t usScibSendDataLenth = 0;

// Received data for SCI-A
#define RX_BUF_NUM_MAX 3
static uint16_t usScibRcvData[RX_BUF_NUM_MAX][SCIB_TXRX_BUF_SIZE];
static uint16_t usScibRcvDataLenth[RX_BUF_NUM_MAX] = {0};
static uint16_t usScibRCVInDataPtr   = 0; //ջָλ
static uint16_t usScibRCVOutDataPrt  = 0; //ջָλ
static uint16_t usScibRcvDataLenthxx = 0;

#define STACK_SIZE  256U
static StaticTask_t vScibISRCoTaskBuffer;
static StackType_t  vScibISRCoTaskStack[STACK_SIZE*2];

//SCIB Black for ISR Notify
static TaskHandle_t xSCIBTaskToNotify = NULL;

//SCIB Black read write Notify
static TaskHandle_t xSCIBReadWriteTaskToNotify = NULL;
static uint16_t usScibWriteDataBlockST = 0;  //1:give notify

//functions
__interrupt void vScibTXFIFOISR(void);
__interrupt void vScibRXFIFOISR(void);
void vScibInitFIFO(uint32_t ulbaud);

//Write data to SCIB
//return: -1 fault ; 0 done
int16_t sScibWrite(uint16_t *dt, uint16_t lenth)
{
    uint16_t i;
    int16_t rtn = 0;

    if(usScibSendDataLenth == 0)
    {
        usScibSendDataLenth = lenth;
        for(i=0; i < usScibSendDataLenth; i++ )
            usScibSendData[i] = dt[i];

        //start send
        HWREGH(SCIB_BASE + SCI_O_FFTX) |= SCI_FFTX_TXFFIENA;
    }
    else
    {
        rtn = -1;
    }

    return rtn;
}

//Read data to SCIB
//return: recieve data lenth
uint16_t usScibRead(uint16_t *buf)
{
    uint16_t i;
    uint16_t size = 0;
    uint16_t *pusData;

    if (usScibRCVInDataPtr == usScibRCVOutDataPrt) //no received
    {
        size = 0;
    }
    else
    {
        size = usScibRcvDataLenth[usScibRCVOutDataPrt];
        pusData = usScibRcvData[usScibRCVOutDataPrt];

        for(i = 0; i < size; i++ )
            buf[i] = pusData[i];

        if (++usScibRCVOutDataPrt == RX_BUF_NUM_MAX)
            usScibRCVOutDataPrt = 0;
    }

    return size;
}

//******************Bloack Read Write SCIB*************************************
//Block Write data to SCIB
//return: -1 fault ; 0 done
int16_t sScibBlockWrite(uint16_t *dt, uint16_t lenth, TickType_t xBlockTime)
{
    uint16_t i;
    int16_t rtn = -1;

    if(usScibSendDataLenth > 0)
    {
        /* Store the handle of the calling task. */
        usScibWriteDataBlockST = 1;
        xSCIBReadWriteTaskToNotify = xTaskGetCurrentTaskHandle();
        ulTaskNotifyTake( pdFALSE, xBlockTime );
    }

    if(usScibSendDataLenth == 0)
    {
        usScibSendDataLenth = lenth;
        for(i=0; i < usScibSendDataLenth; i++ )
            usScibSendData[i] = dt[i];

        //start send
        HWREGH(SCIB_BASE + SCI_O_FFTX) |= SCI_FFTX_TXFFIENA;
    }
    else
    {
        rtn = -1;
    }

    return rtn;
}

//Block Read data to SCIB
//return: recieve data lenth
uint16_t usScibBlockRead(uint16_t *buf, TickType_t xBlockTime)
{
    uint16_t i;
    uint16_t size = 0;
    uint16_t *pusData;

     /* Store the handle of the calling task. */
    xSCIBReadWriteTaskToNotify = xTaskGetCurrentTaskHandle();

    if( ulTaskNotifyTake( pdFALSE, xBlockTime ) > 0)
    {
        if (usScibRCVInDataPtr == usScibRCVOutDataPrt) //no received
        {
            size = 0;
        }
        else
        {
            size = usScibRcvDataLenth[usScibRCVOutDataPrt];
            pusData = usScibRcvData[usScibRCVOutDataPrt];

            for(i = 0; i < size; i++ )
                buf[i] = pusData[i];

            if (++usScibRCVOutDataPrt == RX_BUF_NUM_MAX)
                usScibRCVOutDataPrt = 0;
        }
    }
    return size;
}

//-------------------------------------------------------------------------------------------------
void vScibISRCoTask(void * pvParameters)
{
    uint16_t *pusData;
    //const TickType_t xBlockTime = pdMS_TO_TICS( 500 );
    const TickType_t xBlockTime = (20 / portTICK_PERIOD_MS);  //Block 20ms

    /* Store the handle of the calling task. */
    xSCIBTaskToNotify = xTaskGetCurrentTaskHandle();

    for(;;)
    {
        uint16_t i,j;
        uint16_t send_next_flag = 0;

        #ifdef _USE_WATCHDOG
        //watchdog marsk
        uswatchdogTaskMask |= WD_TASK_MASK_SCIB;
        #endif

        if(SCI_getOverflowStatus(SCIB_BASE)) //clear fifo overflow error
        {
            SCI_performSoftwareReset(SCIB_BASE);
            SCI_clearOverflowStatus(SCIB_BASE);
            SCI_resetRxFIFO(SCIB_BASE);
            usScibRcvDataLenthxx = 0;
        }

        if( ulTaskNotifyTake( pdFALSE, xBlockTime ) > 0)
        {
            //************** send coisr **************************
            if((usScibStatus & SCIB_SEND_ST) == SCIB_SEND_ST)
            {
                ////////send///////
                static uint16_t usSendCnt = 0;

                send_next_flag = 1;
                i = usScibSendDataLenth - usSendCnt;

                //send fifo buff data lenth
                j = 16 - SCI_getTxFIFOStatus(SCIB_BASE);

                if( i == 0 )
                {
                    usSendCnt = 0;
                    j = 0;
                    usScibSendDataLenth = 0;
                    send_next_flag = 0;

                    if(usScibWriteDataBlockST == 1)  //give write notify
                    {
                        xTaskNotifyGive( xSCIBReadWriteTaskToNotify );
                        usScibWriteDataBlockST = 0;
                    }

                    //SCI_clearInterruptStatus(SCIB_BASE, SCI_INT_TXFF);
                    HWREGH(SCIB_BASE + SCI_O_FFTX) |= SCI_FFTX_TXFFINTCLR;
                    // Issue PIE ACK
                    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);
                }
                else if(j > i)
                {
                    j = i;
                }

                for(i = 0; i < j; i++)
                {
                    HWREGH(SCIB_BASE + SCI_O_TXBUF) = usScibSendData[usSendCnt++];
                }

                usScibStatus &= ~SCIB_SEND_ST;

                if(send_next_flag == 1)
                {
                    //SCI_clearInterruptStatus(SCIB_BASE, SCI_INT_TXFF);
                    HWREGH(SCIB_BASE + SCI_O_FFTX) |= SCI_FFTX_TXFFINTCLR;
                    // Issue PIE ACK
                    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);
                    //open TXFF interrupt
                    HWREGH(SCIB_BASE + SCI_O_FFTX) |= SCI_FFTX_TXFFIENA;
                }
                //////// end send /////////
            }

            //************** reciev coisr **************************
            if((usScibStatus & SCIB_RECEIVE_ST) == SCIB_RECEIVE_ST)
            {
                ////////   reciev  ///////
                usScibStatus |= SCIB_RECEIVE_ST_ING;

                //recieved data lenth
                j = SCI_getRxFIFOStatus(SCIB_BASE);

                pusData = usScibRcvData[usScibRCVInDataPtr];

                for(i = 0; i < j; i++)
                {
                    if( usScibRcvDataLenthxx >= SCIB_TXRX_BUF_SIZE )
                    {
                        usScibRcvDataLenthxx = 0;
                    }
                    // Return the character from the receive buffer.
                    pusData[usScibRcvDataLenthxx++] = (uint16_t)
                                       (HWREGH(SCIB_BASE + SCI_O_RXBUF) & SCI_RXBUF_SAR_M);
                }

                ////////end reciev///////
                usScibStatus &= ~SCIB_RECEIVE_ST;

                //SCI_clearInterruptStatus(SCIB_BASE, SCI_INT_RXFF);
                HWREGH(SCIB_BASE + SCI_O_FFRX) |= SCI_FFRX_RXFFINTCLR;
                // Issue PIE ack
                Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);
                //open RXFF interrupt
                HWREGH(SCIB_BASE + SCI_O_FFRX) |= SCI_FFRX_RXFFIENA;
            }
        }
        else
        {
            //recieved data lenth
            j = SCI_getRxFIFOStatus(SCIB_BASE);

            if(j > 0)
            {
                //receive frame end
                if( (usScibStatus & SCIB_RECEIVE_ST_ING) == 0)
                {
                    usScibRcvDataLenthxx = 0;
                }

                pusData = usScibRcvData[usScibRCVInDataPtr];

                for(i = 0; i < j; i++)
                {
                    if( usScibRcvDataLenthxx >= SCIB_TXRX_BUF_SIZE )
                    {
                        usScibRcvDataLenthxx = 0;
                    }
                    // Return the character from the receive buffer.
                    pusData[usScibRcvDataLenthxx++] = (uint16_t)
                                      (HWREGH(SCIB_BASE + SCI_O_RXBUF) & SCI_RXBUF_SAR_M);
                }

                ////////end reciev///////
                usScibStatus &= ~SCIB_RECEIVE_ST_ING;

                /* ݳ */
                usScibRcvDataLenth[usScibRCVInDataPtr] = usScibRcvDataLenthxx;

                /* ׼һν */
                if (++(usScibRCVInDataPtr) == RX_BUF_NUM_MAX) {
                    usScibRCVInDataPtr = 0;
                }

                /* BUFǰһ */
                if (usScibRCVInDataPtr == usScibRCVOutDataPrt)
                {
                  if (++usScibRCVOutDataPrt == RX_BUF_NUM_MAX)
                      usScibRCVOutDataPrt = 0;
                }

                //one frame done
                usScibRcvDataLenthxx = 0;

                if(xSCIBReadWriteTaskToNotify != NULL)  //Notify Read Data
                    xTaskNotifyGive( xSCIBReadWriteTaskToNotify );

                //SCI_clearInterruptStatus(SCIB_BASE, SCI_INT_RXFF);
                HWREGH(SCIB_BASE + SCI_O_FFRX) |= SCI_FFRX_RXFFINTCLR;
                // Issue PIE ack
                Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);
                //open RXFF interrupt
                HWREGH(SCIB_BASE + SCI_O_FFRX) |= SCI_FFRX_RXFFIENA;
            }
            else
            {
                if( (usScibStatus & SCIB_RECEIVE_ST_ING) == SCIB_RECEIVE_ST_ING)
                {
                    ////////end reciev///////
                    usScibStatus &= ~SCIB_RECEIVE_ST_ING;

                    /* ݳ */
                    usScibRcvDataLenth[usScibRCVInDataPtr] = usScibRcvDataLenthxx;

                    /* ׼һν */
                    if (++(usScibRCVInDataPtr) == RX_BUF_NUM_MAX) {
                        usScibRCVInDataPtr = 0;
                    }

                    /* BUFǰһ */
                    if (usScibRCVInDataPtr == usScibRCVOutDataPrt)
                    {
                      if (++usScibRCVOutDataPrt == RX_BUF_NUM_MAX)
                          usScibRCVOutDataPrt = 0;
                    }

                    if(xSCIBReadWriteTaskToNotify != NULL)  //Notify Read Data
                        xTaskNotifyGive( xSCIBReadWriteTaskToNotify );

                    usScibRcvDataLenthxx = 0;
                }
            }
            // end if( j > 0 )
        }
    }
}

//
// initSCIBFIFO - Configure SCIB FIFO
//
void vScibInitFIFO(uint32_t ulbaud)
{
    //
    // 8 char bits, 1 stop bit, no parity. Baud rate is 9600.
    //
    SCI_setConfig(SCIB_BASE, DEVICE_LSPCLK_FREQ, ulbaud, (SCI_CONFIG_WLEN_8 |
                                                        SCI_CONFIG_STOP_ONE |
                                                        SCI_CONFIG_PAR_NONE));
    SCI_enableModule(SCIB_BASE);
    SCI_disableLoopback(SCIB_BASE);
    SCI_resetChannels(SCIB_BASE);
    SCI_enableFIFO(SCIB_BASE);

    //
    // RX and TX FIFO Interrupts Enabled
    //
    //SCI_enableInterrupt(SCIB_BASE, (SCI_INT_RXFF | SCI_INT_TXFF));
    SCI_enableInterrupt(SCIB_BASE, SCI_INT_RXFF);
    SCI_enableInterrupt(SCIB_BASE, SCI_INT_RXERR);

    SCI_setFIFOInterruptLevel(SCIB_BASE, SCI_FIFO_TX8, SCI_FIFO_RX8);
    SCI_performSoftwareReset(SCIB_BASE);

    SCI_resetTxFIFO(SCIB_BASE);
    SCI_resetRxFIFO(SCIB_BASE);

#ifdef AUTOBAUD
    //
    // Perform an autobaud lock.
    // SCI expects an 'a' or 'A' to lock the baud rate.
    //
    SCI_lockAutobaud(SCIB_BASE);
#endif
}


void vScibDeviceInit(uint32_t ulbaud)
{
    //turn on SCIB peripherals
    SysCtl_enablePeripheral(SYSCTL_PERIPH_CLK_SCIB);

    // GPIO is the SCI Rx pin.
    GPIO_setMasterCore(DEVICE_GPIO_PIN_SCIRXDB, GPIO_CORE_CPU1);
    GPIO_setPinConfig(GPIO_87_SCIRXDB);
    GPIO_setDirectionMode(DEVICE_GPIO_PIN_SCIRXDB, GPIO_DIR_MODE_IN);
    GPIO_setPadConfig(DEVICE_GPIO_PIN_SCIRXDB, GPIO_PIN_TYPE_STD);
    GPIO_setQualificationMode(DEVICE_GPIO_PIN_SCIRXDB, GPIO_QUAL_ASYNC);

    // GPIO is the SCI Tx pin.
    GPIO_setMasterCore(DEVICE_GPIO_PIN_SCITXDB, GPIO_CORE_CPU1);
    GPIO_setPinConfig(GPIO_86_SCITXDB);
    GPIO_setDirectionMode(DEVICE_GPIO_PIN_SCITXDB, GPIO_DIR_MODE_OUT);
    GPIO_setPadConfig(DEVICE_GPIO_PIN_SCITXDB, GPIO_PIN_TYPE_STD);
    GPIO_setQualificationMode(DEVICE_GPIO_PIN_SCITXDB, GPIO_QUAL_ASYNC);

    // Interrupts that are used in this example are re-mapped to
    // ISR functions found within this file.
    Interrupt_register(INT_SCIB_RX, vScibRXFIFOISR);
    Interrupt_register(INT_SCIB_TX, vScibTXFIFOISR);

    // Initialize the Device Peripherals:
    vScibInitFIFO(ulbaud);

    Interrupt_enable(INT_SCIB_RX);
    Interrupt_enable(INT_SCIB_TX);

    SCI_clearInterruptStatus(SCIB_BASE, SCI_INT_TXFF);
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);

    // Create the task without using any dynamic memory allocation.

    xTaskCreateStatic(vScibISRCoTask,         // Function that implements the task.
                      "SCIB task",      // Text name for the task.
                      STACK_SIZE*2,           // Number of indexes in the xStack array.
                      ( void * ) NULL,      // Parameter passed into the task.
                      configMAX_PRIORITIES - 2, // Priority at which the task is created.
                      vScibISRCoTaskStack,        // Array to use as the task's stack.
                      &vScibISRCoTaskBuffer );    // Variable to hold the task's data structure.



}

//
// scibTXFIFOISR - SCIb Transmit FIFO ISR
//
__interrupt void vScibTXFIFOISR(void)
{
    BaseType_t xHigherPriorityTaskWoken;

//    //SCI_clearInterruptStatus(SCIB_BASE, SCI_INT_TXFF);
//    HWREGH(SCIb_BASE + SCI_O_FFTX) |= SCI_FFTX_TXFFINTCLR;
//
//    // Issue PIE ACK
//    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);

    //disable tx interrupt
    HWREGH(SCIB_BASE + SCI_O_FFTX) &= ~SCI_FFTX_TXFFIENA;

    //set send isr flag
    usScibStatus |= SCIB_SEND_ST;

    //send TaskNotify to vScibISRCoTask
    xHigherPriorityTaskWoken = pdFALSE;
    vTaskNotifyGiveFromISR( xSCIBTaskToNotify, &xHigherPriorityTaskWoken );
    portYIELD_FROM_ISR( xHigherPriorityTaskWoken );
}

//
// scibRXFIFOISR - SCIB Receive FIFO ISR
//
__interrupt void vScibRXFIFOISR(void)
{
    BaseType_t xHigherPriorityTaskWoken;

    if((HWREGH(SCIB_BASE + SCI_O_FFRX) & SCI_FFRX_RXFFINT) == SCI_FFRX_RXFFINT)
    {
//        //SCI_clearInterruptStatus(SCIB_BASE, SCI_INT_RXFF);
//        HWREGH(SCIB_BASE + SCI_O_FFRX) |= SCI_FFRX_RXFFINTCLR;
//
//        // Issue PIE ack
//        Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);

        //close RXFF interrupt
        HWREGH(SCIB_BASE + SCI_O_FFRX) &= ~SCI_FFRX_RXFFIENA;

        //set recieved isr flag
        usScibStatus |= SCIB_RECEIVE_ST;

        //send TaskNotify to vScibISRCoTask
        xHigherPriorityTaskWoken = pdFALSE;
        vTaskNotifyGiveFromISR( xSCIBTaskToNotify, &xHigherPriorityTaskWoken );
        portYIELD_FROM_ISR( xHigherPriorityTaskWoken );
    }
    else if( (HWREGH(SCIB_BASE + SCI_O_RXST) & (SCI_RXST_RXERROR)) == SCI_RXST_RXERROR )
    {
         SCI_performSoftwareReset(SCIB_BASE);
         SCI_resetRxFIFO(SCIB_BASE);
         usScibRcvDataLenthxx = 0;
    }
    else if(SCI_getOverflowStatus(SCIB_BASE))
    {
        SCI_clearOverflowStatus(SCIB_BASE);
        SCI_resetRxFIFO(SCIB_BASE);
        usScibRcvDataLenthxx = 0;
    }
}

