/*
 * sysclock_device.h
 *
 *  Created on: 2023123
 *      Author: QA
 */

#ifndef DEVICE_SYSCLOCK_DEVICE_H_
#define DEVICE_SYSCLOCK_DEVICE_H_


//*****************************************************************************
//
// Defines related to clock configuration
//
//*****************************************************************************

// 20MHz XTAL on controlCARD. For use with SysCtl_getClock().
//
#define DEVICE_OSCSRC_FREQ          20000000U

//
// Define to pass to SysCtl_setClock(). Will configure the clock as follows:
// PLLSYSCLK = 20MHz (XTAL_OSC) * 20 (IMULT) * 1 (FMULT) / 2 (PLLCLK_BY_2)
//
#define DEVICE_SETCLOCK_CFG         (SYSCTL_OSCSRC_XTAL | SYSCTL_IMULT(20) |  \
                                     SYSCTL_FMULT_NONE | SYSCTL_SYSDIV(2) |   \
                                     SYSCTL_PLL_ENABLE)

//
// 200MHz SYSCLK frequency based on the above DEVICE_SETCLOCK_CFG. Update the
// code below if a different clock configuration is used!
//
#define DEVICE_SYSCLK_FREQ          ((DEVICE_OSCSRC_FREQ * 20 * 1) / 2)


//
// 50MHz LSPCLK frequency based on the above DEVICE_SYSCLK_FREQ and a default
// low speed peripheral clock divider of 4. Update the code below if a
// different LSPCLK divider is used!
//
#define DEVICE_LSPCLK_FREQ          (DEVICE_SYSCLK_FREQ / 4)

//*****************************************************************************
//
// Macro to call SysCtl_delay() to achieve a delay in microseconds. The macro
// will convert the desired delay in microseconds to the count value expected
// by the function. \b x is the number of microseconds to delay.
//
//*****************************************************************************
#define DEVICE_DELAY_US(x) SysCtl_delay(((((long double)(x)) / (1000000.0L /  \
                              (long double)DEVICE_SYSCLK_FREQ)) - 9.0L) / 5.0L)

#define DEVICE_DELAY_US1(x) SysCtl_delay(((((long double)(x)) / (10000000.0L /  \
                              (long double)DEVICE_SYSCLK_FREQ)) - 9.0L) / 5.0L)



#define CONF_PWMSYSCLOCK_FREQ_HZ ((float32_t)100*1000000)
#define CONF_CPU_SYS_CLOCK_FREQ_HZ ((float32_t)200*1000000)
#define CONF_ECAPSYSCLOCK_FREQ_HZ	((float32_t)200*1000000)

#endif /* DEVICE_SYSCLOCK_DEVICE_H_ */
