/*
 * watchdog_device.c
 *
 *  Created on: 20231213
 *      Author: QA
 */
#define  _USE_GLOBALS

#include "device.h"
#include "watchdog_device.h"
#include "led_device.h"
#include "sys_config.h"

#define vResetSystemCall ((void (*)(void))((uintptr_t)0x3FF16A))

// Wakeup ISR - The interrupt service routine called when the watchdog
//              triggers the wake interrupt signal
__interrupt void vWatchdogISR(void)
{
    static uint16_t dt = 0;

    uswatchdogISRCount++;

    if( uswatchdogISRCount > 1)  // >= 0.843 *2, than reset system
    {
        ////// Handling peripherals that need to be shut down //////



        //vLED3TurnOn();
        ///////////////////   End Handling   //////////////////////

        DINT;
        DRTM;
    //    vResetSystemCall();
    }

    if( (dt++ & 0x01) == 0x01 )
        vLED2TurnOn();
    else
        vLED2TurnOff();

    // Acknowledge this interrupt located in group 1
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP1);
}


void vWatchdogDeviceInit(void)
{
    // Set the watchdog to generate an interrupt signal instead of a
    // reset signal
    SysCtl_setWatchdogMode(SYSCTL_WD_MODE_INTERRUPT);
    //vSysCtl_setWatchdogPreDivScaler(SYSCTL_WD_PREDIVIDE_2048, SYSCTL_WD_PRESCALE_64);  //843ms
    SysCtl_setWatchdogPrescaler(SYSCTL_WD_PRESCALE_64);

    // Re-map watchdog wake interrupt signal to call the ISR function
    Interrupt_register(INT_WAKE, vWatchdogISR);

    // Reset the watchdog counter
    vSysCtl_serviceWatchdog();

    // Enable the watchdog
    SysCtl_enableWatchdog();
    Interrupt_enable(INT_WAKE);

    uswatchdogTaskMask = 0;
}

void vApplicationIdleHook( void )
{
    //heartbeat LED
    static uint32_t t0 = 0;

    if((t0 - TIM_50us_COUNTER ) > 10000)  //500ms
    {
        t0 = TIM_50us_COUNTER;
        vToggleLED1();
    }

    if( uswatchdogTaskMask == WD_TASK_MASK_ALL)
    {
        // Reset the watchdog counter
        vSysCtl_serviceWatchdog();
    }
}
