/*
 * watchdog_device.h
 *
 *  Created on: 20231213
 *      Author: QA
 */

#ifndef DEVICE_WATCHDOG_DEVICE_H_
#define DEVICE_WATCHDOG_DEVICE_H_

#ifdef  _USE_GLOBALS
#define _EXT_VAR
#else
#define _EXT_VAR extern
#endif

_EXT_VAR uint16_t uswatchdogTaskMask;
_EXT_VAR uint16_t uswatchdogISRCount;

#define WD_TASK_MASK_SCIA           0x01
#define WD_TASK_MASK_SCIB           0x02
#define WD_TASK_MASK_HEARTBEAT      0x04
#define WD_TASK_MASK_UPDATE	        0x08
#define WD_TASK_MASK_SYSMANAGE      0x10

//#define WD_TASK_MASK_SCIAMBBUS      0x04

#define WD_TASK_MASK_ALL           (  WD_TASK_MASK_SCIA 	\
									| WD_TASK_MASK_SCIB		\
									| WD_TASK_MASK_HEARTBEAT \
									| WD_TASK_MASK_UPDATE 	\
									| WD_TASK_MASK_SYSMANAGE )	

//*****************************************************************************
//
//! The following are values that can be passed to
//! SysCtl_setWatchdogPrescaler() as the \e pre-divider parameter.
//
//*****************************************************************************
typedef enum
{
    SYSCTL_WD_PREDIVIDE_512  =  0x0000,      //!< PREDIVCLK = INTOSC1 / 512
    SYSCTL_WD_PREDIVIDE_1024  = 0x0100,      //!< PREDIVCLK = INTOSC1 / 1024
    SYSCTL_WD_PREDIVIDE_2048  = 0x0200,      //!< PREDIVCLK = INTOSC1 / 2048
    SYSCTL_WD_PREDIVIDE_4096  = 0x0300,      //!< PREDIVCLK = INTOSC1 / 4096
    SYSCTL_WD_PREDIVIDE_2 = 0x0800,          //!< PREDIVCLK = INTOSC1 / 2
    SYSCTL_WD_PREDIVIDE_4 = 0x0900,          //!< PREDIVCLK = INTOSC1 / 4
    SYSCTL_WD_PREDIVIDE_8 = 0x0A00,          //!< PREDIVCLK = INTOSC1 / 8
    SYSCTL_WD_PREDIVIDE_16 = 0x0B00,         //!< PREDIVCLK = INTOSC1 / 16
    SYSCTL_WD_PREDIVIDE_32 = 0x0C00,         //!< PREDIVCLK = INTOSC1 / 32
    SYSCTL_WD_PREDIVIDE_64 = 0x0D00,         //!< PREDIVCLK = INTOSC1 / 64
    SYSCTL_WD_PREDIVIDE_128 = 0x0E00,        //!< PREDIVCLK = INTOSC1 / 128
    SYSCTL_WD_PREDIVIDE_256 = 0x0F00,        //!< PREDIVCLK = INTOSC1 / 256
} eSysCtl_WDPredivider;

//*****************************************************************************
//
//! Sets up watchdog clock (WDCLK) Pre-divider and prescaler.
//!
//! \param pre-divider is the value that configures the pre-divider clock relative
//! to the value from the INTOSC1.
//
//! \param prescaler is the value that configures the watchdog clock relative
//! to the value from the pre-divider.
//!
//! This function sets up the watchdog clock (WDCLK) prescaler. The
//! \e prescaler parameter divides INTOSC1 down to WDCLK.
//!
//! \return None.
//
//*****************************************************************************
static inline void
vSysCtl_setWatchdogPreDivScaler(eSysCtl_WDPredivider epredivider, SysCtl_WDPrescaler eprescaler)
{
    uint16_t regVal;

    regVal = (uint16_t)epredivider | (uint16_t)eprescaler | (uint16_t)SYSCTL_WD_CHKBITS;

    EALLOW;

    //
    // Write the prescaler to the appropriate register.
    //
    HWREGH(WD_BASE + SYSCTL_O_WDCR) = (HWREGH(WD_BASE + SYSCTL_O_WDCR) &
                                       ~(SYSCTL_WDCR_WDPS_M | 0x0F00)) | regVal;

    EDIS;
}

static inline void
vSysCtl_serviceWatchdog(void)
{
    EALLOW;

    //
    // Enable the counter to be reset and then reset it.
    //
    HWREGH(WD_BASE + SYSCTL_O_WDKEY) = SYSCTL_WD_ENRSTKEY;
    HWREGH(WD_BASE + SYSCTL_O_WDKEY) = SYSCTL_WD_RSTKEY;

    EDIS;
    uswatchdogISRCount = 0;  //reset to 0
}

void vWatchdogDeviceInit(void);

#endif /* DEVICE_WATCHDOG_DEVICE_H_ */
